%% This is file `arxbj.cls'
%%
%% LaTeX 2e class file for the processing of LaTeX2e files
%% of the following The Bernoulli  Society / IMS journals:
%%
%%   Journal "Bernoulli"
%%
%% Macros written by Vytas Statulevicius, VTeX, Lithuania
%% for Institute of Mathematical Statistics, U.S.A.
%% Please submit bugs or your comments to vytas@vtex.lt
%%
%% These class file is a simplified version of style files,
%% used in a professional typesetting of the above mentioned journals.
%% The main purpose of this class is to let users compile files
%% downloaded from the arXiv 
%%
%% The following macro packages are required:
%%   textcomp.sty
%%   amssymb.sty
%%   amsfonts.sty
%%   bm.sty
%%   texsort.sty
%%   keyval.sty
%%   natbib.sty
%%
%% You are free to use this class file as you see fit, provided 
%% that you do not make changes to the file. 
%% If you DO make changes, you are required to rename this file.
%%
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
%%
%% Bug fixes and changes:
% 2007.08.23 - start
% 2011.06.15 - msnbibl macros added 
% 2012.01.23 - firstpage fixed
% 2012.05.15 - ivestas supplement
% 2012.05.15 - pataisytas supplement
% 2012.06.20 - vtexurl macros added; supplement indentation (ES)
%            - paragraph indentation after end of theorem (ES)
% 2013.07.24 - bibliography commands \blocation and \bsuffix added (ES)
% 2014.01.31 - dedicated added (ES) 
% 2014.03.07 - inits output hid (ES) 
% 2014.07.04 - pmid, pmcid, mid (bid keys) added (ES) 
% 2014.07.30 - auto runauthor added (ES) 

\def\fmt@name{arxbj}
\def\fmt@version{2014/07/30}

\NeedsTeXFormat{LaTeX2e}[2000/06/01]
\ProvidesClass{bj}
              [\fmt@version,
 Bernoulli]

% Definitions:
\newcommand\bibname{References}
\newcommand\appendixname{Appendix}
\newcommand\abstractname{}
\newcommand\acknowledgementsname{Acknowledgements}

\newcommand\@ptsize{}
\newif\if@restonecol \@restonecolfalse
\newif\if@openright  \@openrightfalse

% General Options
\DeclareOption{draft}{\setlength\overfullrule{5pt}}
\DeclareOption{final}{\setlength\overfullrule{0pt}}
\DeclareOption{openright}{\@openrighttrue}
\DeclareOption{openany}{\@openrightfalse}
\DeclareOption{onecolumn}{\@twocolumnfalse\@restonecoltrue}
\DeclareOption{twocolumn}{\@twocolumntrue}

\newif\if@noMRlinks \@noMRlinksfalse
\DeclareOption{noMRlinks}{\@noMRlinkstrue}

\newif\if@MSNbibl \@MSNbiblfalse
\DeclareOption{MSNbibl}{\@MSNbibltrue}

% Put "." after inline section headings:
\newif\if@autosecdot 
\DeclareOption{autosecdot}  {\@autosecdottrue}
\DeclareOption{noautosecdot}{\AtBeginDocument{\@autosecdotfalse}}

% Information about journals
\def\journal@issn{1350-7265}
\def\journal@name{Bernoulli}
\def\journal@url{http://isi.cbs.nl/bernoulli/}
\def\owner@url{http://isi.cbs.nl/BS/bshome.htm}
\def\@jid{BEJ}

% bibliography
\newif\if@nameyear \@nameyearfalse 
\DeclareOption{nameyear}{\global\@nameyeartrue}
\DeclareOption{number}{\global\@nameyearfalse}

% vtexflt.sty
\def\float@numbering{0}
\DeclareOption{normalfloat}{\def\float@numbering{0}}
\DeclareOption{secfloat}   {\def\float@numbering{1}}
\DeclareOption{chapfloat}  {\def\float@numbering{2}}
\DeclareOption{rotating}{\AtEndOfClass{\RequirePackage[dvips,counterclockwise,figuresright]{rotating}}}%

% vtexmth.sty
\def\eqn@numbering{0}
\DeclareOption{normaleqn}{\def\eqn@numbering{0}}
\DeclareOption{seceqn}   {\def\eqn@numbering{1}}
\DeclareOption{chapeqn}  {\def\eqn@numbering{2}}

% vtexthm.sty
\def\thm@numbering{0}
\DeclareOption{normalthm}{\def\thm@numbering{0}}
\DeclareOption{secthm}   {\def\thm@numbering{1}}
\DeclareOption{chapthm}  {\def\thm@numbering{2}}
\newif\if@xx@theorem \@xx@theoremfalse 
\DeclareOption{xxtheorem}{\global\@xx@theoremtrue} 

% hyperref.sty
\newif\if@loadhyperref
\DeclareOption{nohyperref}{\global\@loadhyperreffalse}
\@loadhyperreftrue

\ExecuteOptions{10pt,twoside,final,onecolumn,nameyear}
\ProcessOptions

%************************* FONTS

\renewcommand\normalsize{%
   \@setfontsize\normalsize\@xpt{12pt plus .3pt minus .3pt}%
   \abovedisplayskip 10\p@ \@plus2\p@ \@minus2\p@
   \abovedisplayshortskip 6\p@ \@plus2\p@
   \belowdisplayshortskip 6\p@ \@plus2\p@
   \belowdisplayskip \abovedisplayskip}

\newcommand\small{%
   \@setfontsize\small\@ixpt{11\p@ plus .2\p@ minus .2\p@}%
   \abovedisplayskip 7.5\p@ \@plus4\p@ \@minus1\p@
   \belowdisplayskip \abovedisplayskip
   \abovedisplayshortskip \abovedisplayskip
   \belowdisplayshortskip \abovedisplayskip}

\newcommand\footnotesize{%
   \@setfontsize\footnotesize\@viiipt{10\p@ plus .1pt minus .1pt}%%
   \abovedisplayskip 6\p@ \@plus4\p@ \@minus1\p@
   \belowdisplayskip \abovedisplayskip
   \abovedisplayshortskip \abovedisplayskip
   \belowdisplayshortskip \abovedisplayskip}

\newcommand\scriptsize{\@setfontsize\scriptsize\@viipt\@viiipt}
\newcommand\tiny{\@setfontsize\tiny\@vpt\@vipt}
\newcommand\large{\@setfontsize\large\@xiipt{14}}
\newcommand\Large{\@setfontsize\Large\@xivpt{16}}
\newcommand\LARGE{\@setfontsize\LARGE\@xvipt{18}}
\newcommand\huge{\@setfontsize\huge\@xviiipt{20}}
\newcommand\Huge{\@setfontsize\Huge\@xxpt{24}}

% Compatibility with old latex:
\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\let\sl\it
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\@nomath\sc}

% ********************* DIMENSIONS:
% TEXT DIMENSIONS
\setlength\parindent    {10\p@}
\def\sv@parindent       {10\p@}
\setlength\textwidth    {32pc}
\setlength\textheight   {43pc} %44 eil.
\advance\textheight by\topskip
\setlength\columnsep    {1pc}
\setlength\columnwidth  {30.5pc}
\setlength\columnseprule{0\p@}

% HEADS:
\setlength\headheight{12\p@}
\setlength\headsep   {14\p@}
\setlength\topskip   {10\p@}
\setlength\footskip  {24\p@}
\setlength\maxdepth  {.5\topskip}

% PAPER AND TRIM SIZE
\setlength\paperwidth  {8.5in}
\@settopoint\paperwidth
\setlength\paperheight {11in}
\@settopoint\paperheight

% CENTER ON PAGE
    \setlength\@tempdima        {\the\paperwidth}
    \addtolength\@tempdima      {-\textwidth}
    \setlength\oddsidemargin    {.5\@tempdima}
    \addtolength\oddsidemargin  {-1in}
    \evensidemargin=\oddsidemargin
    \@settopoint\evensidemargin
    \@settopoint\oddsidemargin

    \setlength\@tempdima        {\the\paperheight}
    \addtolength\@tempdima      {-\textheight}
    \setlength\topmargin    {.5\@tempdima}
    \addtolength\topmargin  {-1in}

\if@twocolumn
 \setlength\marginparsep {10\p@}
\else
  \setlength\marginparsep{7\p@}
\fi
\setlength\marginparpush {5\p@}

% TEXT PARAMETERS
\setlength\lineskip{1\p@}
\setlength\normallineskip{1\p@}
\renewcommand\baselinestretch{}
\setlength\parskip{0\p@}

% BREAKS
\setlength\smallskipamount{6\p@ \@plus 1\p@ \@minus 1\p@}
\setlength\medskipamount  {12\p@ \@plus 3\p@ \@minus 2\p@}
\setlength\bigskipamount  {18\p@ \@plus 3\p@ \@minus 2\p@}

% PAGE-BREAKING PENALTIES
\clubpenalty=10000
\widowpenalty=10000
\displaywidowpenalty=50
\predisplaypenalty=10000   % Breaking before a math display.
\pretolerance=100    % Badness tolerance for the first pass (before hyphenation)
\tolerance=800       % Badness tolerance after hyphenation
\hbadness=800        % Badness above which bad hboxes will be shown
\emergencystretch=3\p@
\hfuzz=1\p@           % do not be to critical about boxes

% FOOTNOTES
\setlength\footnotesep   {7\p@}
\setlength{\skip\footins}{18\p@ \@plus 4\p@ \@minus 2\p@}
\skip\@mpfootins = \skip\footins

% FRAMED BOXES
\setlength\fboxsep{3\p@}
\setlength\fboxrule{.4\p@}

%************************* LOADING PACKAGES:

\normalfont\normalsize

\RequirePackage[psamsfonts]{amssymb}
\newcommand\hmmax{0}
\newcommand\bmmax{1}
\RequirePackage{bm}

% FRONT MATTER MACROS

%%%% start of vtexfmpdf - 2007/02/21 VTEX front matter general macros (VS)

%%%%%%%%%%%%%% Options
\newif\if@journal 

\@journaltrue

\RequirePackage{texsort}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% setattribute, getattribute, do@option@list

\def\setattribute{\@ifnextchar[\@setattribute{\@setattribute[]}}
\long\def\@setattribute[#1]#2#3#4{\long\expandafter\gdef\csname #2@#3\endcsname{#4}}
\def\getattribute#1#2{\csname #1@#2\endcsname}
\def\sep@key@value#1=#2/?/#3{\setattribute{#3}{#1}{#2}}
\def\do@option@list#1#2{%
  \@for\curr@option:={#2}\do{%
    \expandafter\sep@key@value\curr@option/?/{#1}\relax
  }%
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% firstpage, lastpage, pagerange, pagenumbering

\def\firstpage#1{\def\@tempa{#1}\ifx\@tempa\@empty\else
  \gdef\@firstpage{#1}\gdef\@lastpage{#1}%
%  \global\c@page=#1 
  \ignorespaces\fi}

\def\lastpage#1{\def\@tempa{#1}\ifx\@tempa\@empty\else
  \gdef\@lastpage{#1}\ignorespaces\fi}

\def\@firstpage{1}
\def\@lastpage{0}

\def\pagerange@sep{--}
\def\set@pagerange{%
    \ifx\@firstpage\@lastpage%
       \gdef\@pagerange{\@firstpage}%
    \else%
       \gdef\@pagerange{\@firstpage\pagerange@sep\@lastpage}%
    \fi}
\def\@pagerange{1\pagerange@sep 0}

\def\pagenumbering#1{%
  \def\@tempa{\csname none\endcsname}%
  \def\@tempb{\csname #1\endcsname}%
  \ifx\@tempa\@tempb
    \global\let\thepage\relax
    \gdef\firstpage##1{\gdef\@firstpage{}\dbl@error{Su \string\pagenumbering{none} \string\firstpage\space nenaudojamas!}}%
    \gdef\lastpage##1{\gdef\@lastpage{}\dbl@error{Su \string\pagenumbering{none} \string\lastpage\space nenaudojamas!}}%
  \else
    \gdef\thepage{\csname @#1\endcsname\c@page}%
  \fi
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% journal, volume, issue, pubyear

\if@journal

% JOURNAL
\def\journal#1{\gdef\@journal{#1}}     
\@ifundefined{@journal}{\gdef\@journal{Journal not defined}}{}

% VOLUME
\setattribute{volume} {multisep}{--} %1,2,3 -> 1-3
\setattribute{volume} {twosep}  {--} %1,2   -> 1-2

\setattribute{volume} {multilabel} {Vols.} %1,2,3 -> Vols.
\setattribute{volume} {twolabel}   {Vols.} %1,2   -> Vols.
\setattribute{volume} {label}      {Vol.}  %1     -> Vol.

\def\volume#1{%
  \initarray{@tempa}{#1}\@tempcnta\getarraylenght{@tempa}\relax%
  \ifnum\@tempcnta>1\global\let\volume@label\volume@twolabel\fi%
  \ifnum\@tempcnta>2\global\let\volume@label\volume@multilabel\fi%
  \compresslist{#1}\to{multivol@list}\sep{\volume@twosep}{\volume@multisep}%
  \expandafter\gdef\expandafter\@volume\expandafter{\multivol@list}}

\def\@volume{0}

%% ISSUE
\setattribute{issue} {multisep} {--} %1,2,3 -> 1-3
\setattribute{issue} {twosep}   {--} %1,2   -> 1-2

\setattribute{issue} {multilabel} {Nos.} %1,2,3 -> Nos.
\setattribute{issue} {twolabel}   {Nos.} %1,2   -> Nos.
\setattribute{issue} {label}      {No.}  %1     -> No.

\def\issue#1{%
  \initarray{@tempa}{#1}\@tempcnta\getarraylenght{@tempa}\relax%
  \ifnum\@tempcnta=1 \gdef\@issue{#1}%
  \else%
    \ifnum\@tempcnta>1\global\let\issue@label\issue@twolabel\fi%
    \ifnum\@tempcnta>2\global\let\issue@label\issue@multilabel\fi%
    \compresslist{#1}\to{multiissue@list}\sep{\issue@twosep}{\issue@multisep}%
    \expandafter\gdef\expandafter\@issue\expandafter{\multiissue@list}%
  \fi%
  }


\def\@issue{0}

% PUBYEAR
% \@pubyear 2001
% \copyyear   01

\newcount\@pubyear
\newcount\@copyear

\bgroup
  \global\@pubyear=\number\year
  \def\tmp@a{\expandafter\@gobbletwo\the\year}
  \global\@copyear\number\tmp@a\relax
\egroup

\def\pubyear#1{\global\@pubyear#1\relax\gdef\@crtyr{#1}%
  \expandafter\global\expandafter\@copyear\@gobbletwo#1\relax
  \ignorespaces}

\fi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% startlocaldefs, endlocaldefs

\def\startlocaldefs{\makeatletter}
\def\endlocaldefs{\makeatother}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% thanksref, thanksmark, thankslabel, thankstext

\def\saferef#1{\expandafter\safe@setref\csname r@#1\endcsname\@firstoftwo{#1}}
\let\safe@setref\@setref

\def\safelabel#1{\@bsphack
  \protected@write\@auxout{}%
         {\string\thanksnewlabel{#1}{{\@currentlabel}{\thepage}}}%
  \@esphack}

% {url}{text}
\def\safe@href#1#2{#2}

\let\thanksnewlabel\newlabel

% we want to use various counters:
\def\usethankscounter#1{%
  \@ifundefined{current@thankscounter}{\gdef\previous@thankscounter{#1}}{\xdef\previous@thankscounter{\current@thankscounter}}%
  \def\current@thankscounter{#1}}

\def\restorethankscounter{\xdef\current@thankscounter{\previous@thankscounter}}

% pagrindinis counteris
\newcounter{thanks}
\def\thethanks{\arabic{thanks}}
\usethankscounter{thanks}

% galimas papildomas counteris: address ref
% \newcounter{addressref}
% \def\theaddressref{\arabic{addressref}}

%\def\thanksmark@fmt#1{\hbox{$^{#1}$}}
\let\thanksmark@shape\relax
\def\thanksmark@fmt#1{\@textsuperscript{\normalfont\thanksmark@shape#1}}
\def\thanksref@sep{,}

% hooks for the hyperref:
\def\thankref@hyperlink#1{\saferef{#1thanks}}
\def\thanks@hypertarget#1{}
\def\thanksmark@link#1#2{#2}

% Apibrezimas *hyperref*
%  \def\thankref@hyperlink#1{\edef\@tempx{#1thanks}\hyperlink{#1}{\saferef{\@tempx}}}
%  \def\thanks@hypertarget#1{\smash{\raise\baselineskip\hbox{\protect\hypertarget{#1}{}}}}
%  \def\thanksmark@link#1#2{\hyperlink{#1}{#2}}

% Apibrezimas *hypermark*
%  \@ifundefined{fmt@empty@thanksanchor}{\let\fmt@empty@thanksanchor\@gobble}{}
%  \def\thankref@hyperlink#1{\edef\@tempx{#1thanks}\ref{\@tempx}}
%  \def\thanks@hypertarget#1{\protect\fmt@empty@thanksanchor{#1thanks}}
%  \def\thanksmark@link#1#2{\b@cite@color\hyper@linkstart{link}{#1thanks.label}#2\hyper@linkend\e@cite@color}

% Isvedame zymes
\def\thanksref{\@ifnextchar[{\@tempswatrue\@thanksref}{\@tempswafalse\@thanksref[]}}

\def\@thanksref[#1]#2{%
  \if@tempswa% []
    \let\thanksref@first\relax%
    \@for\@@refb:=#2\do{\ifx\relax\thanksref@first\relax\xdef\thanksref@first{\@@refb}\fi}%
    \thanksmark@link{\thanksref@first}{\thanksmark@fmt{#1}}%
  \else%
    \let\@tempa\@empty%
    \thanksmark@fmt{\@for\@tempb:=#2\do{%
       \@tempa\let\@tempa\thanksref@sep%
       \edef\@tempb{\expandafter\@firstofone\@tempb\@empty}%
       \thankref@hyperlink{\@tempb}}}%
   \fi}

% Suformuojame ir isvedame zyme
\def\thanksmark{\@ifnextchar[{\@tempswatrue\@thanksmark}{\@tempswafalse\@thanksmark[]}}

\def\@thanksmark[#1]#2{%
   \@thankslabel[#1]{#2}%
   \safelabel{#2thanks}%
   \thanksmark@fmt{\expandafter\saferef{#2thanks}\thanks@hypertarget{#2}}}

% Suformuojame tik zyme
\def\thankslabel{\@ifnextchar[{\@tempswatrue\@thankslabel}{\@tempswafalse\@thankslabel[]}}

\def\@thankslabel[#1]#2{%
   \if@tempswa% []
     \protected@edef\@currentlabel{#1}%
   \else% 
     \refstepcounter{\current@thankscounter}%
   \fi%
   \safelabel{#2thanks}}%

% Suformuojame zyme ir idedame teksta i \@thanks:
\def\thankstext{\@ifnextchar[{\@tempswatrue\@thankstext}{\@tempswafalse\@thankstext[]}}

\def\@thankstext[#1]#2#3{%
  \@thankslabel[#1]{#2}%
  \protected@xdef\@thanks{\@thanks\protect\thanks@thefnmark{#2thanks}%
  \protect\@footnotetext{\thanks@hypertarget{#2}#3}}}%

\def\thanks@thefnmark#1{\begingroup\unrestored@protected@xdef\@thefnmark{\saferef{#1}}\endgroup}%

% ST makrosas savo numeracijos sistemos sukurimui
\def\setvaluelist#1#2{\@tempcnta=0\relax
  \@for\@curr@val:=#2\do{%
     \advance\@tempcnta by1\relax
     \expandafter\protected@xdef\csname #1@item@\the\@tempcnta\endcsname{\@curr@val}%
     }%
     \expandafter\protected@xdef\csname #1@item@0\endcsname{\the\@tempcnta}%
}
\xdef\getitemvalue#1#2{\noexpand\csname #1@item@#2\endcsname}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% \ead, \printead

\RequirePackage{keyval}

\def\email@text{e-mail: }
\def\url@text{url: }
\def\fullurl@text{url: }
\def\ead@sep{;~}
\let\ead@size\relax
\def\printead@fmt#1{#1}

% naudojame keyval paketa
\define@key{ead}{email}[true]{\def\ead@type{email}}
\define@key{ead}{url}[true]{\def\@tempa{fullurl}\ifx\ead@type\@tempa\else\def\ead@type{url}\fi}
\define@key{ead}{label}{\def\ead@label{#1}}

%%%% 2007.08.28 \label pakeistas i \safelabel

\define@key{ead}{text}{%
  \bgroup%
    \def\\{\string\break}%
    \def\break{\string\break}%
    \protected@edef\@currentlabel{#1}%
    \safelabel{\ead@label @\ead@type text}%
  \egroup}

\define@key{ead}{nopdflink}[true]{%
   \protected@edef\@currentlabel{nolink}%
   \safelabel{\ead@label @nopdflink}}

\DeclareRobustCommand\ead[2][label= ,email]{{%
  \def\ead@type{email}% default
  \checkead@prefix#2://\end%
  \def\texttildelow{\noexpand\texttildelow}%
  \setkeys{ead}{#1}%
  \csname ead@hook\endcsname%
  \protected@edef\@currentlabel{#2}%
  \safelabel{\ead@label @\ead@type}}}

\def\checkead@prefix#1://#2\end{\ifx.#2.\else\def\ead@type{fullurl}\fi}

\newif\ifnot@ead@star
\newif\if@printead@opt

\DeclareRobustCommand{\printead}{\@ifstar{\not@ead@starfalse\@printead}{\not@ead@startrue\@printead}}

\def\@printead{\@ifnextchar[{\@printead@opttrue\@@printead}{\@printead@optfalse\@@printead[]}}

\def\@@printead[#1]#2{{%
   \if@printead@opt%[]
      \def\safe@href@text{#1}%
      \not@ead@starfalse%
   \fi%      
   \let\prev@ead@text\relax%
   \let\@ead@sep\relax%
   \let\ead@text\relax%
   \let\ead@prefix\relax%
   \def\ead@type{}%
   \@tempcnta=0%
   \let\sv@safe@href\safe@href%
   \printead@fmt{\@for\ead@ref:=#2\do{%
       \advance\@tempcnta by1%
       \let\safe@href\sv@safe@href%
       \@ead@sep\let\@ead@sep\ead@sep%
       \@ifundefined{r@\ead@ref @nopdflink}{}{\def\safe@href##1##2{##2}}%
       \@ifundefined{r@\ead@ref @email}{}{\let\ead@text\email@text\def\ead@type{email}\def\ead@prefix{mailto:}}%
       \@ifundefined{r@\ead@ref @url}{}{\let\ead@text\url@text\def\ead@type{url}\def\ead@prefix{http://}}%
       \@ifundefined{r@\ead@ref @fullurl}{}{\let\ead@text\fullurl@text\def\ead@type{fullurl}\def\ead@prefix{}}%
       \ifx\prev@ead@text\ead@text\let\ead@text\relax\fi%
       \csname printead@hook\endcsname%
       \if@printead@opt\ifnum\@tempcnta>1\@latex@error{Command \@backslashchar printead[]{e1} could have only one parameter "e1"!}\@eha\fi%
       \else\@ifundefined{r@\ead@ref @\ead@type text}{\def\safe@href@text{\saferef{\ead@ref @\ead@type}}}{\def\safe@href@text{\saferef{\ead@ref @\ead@type text}}}\fi%
       \ifnot@ead@star\ead@text\fi{\ead@size\def\null{}\safe@href{\ead@prefix\saferef{\ead@ref @\ead@type}}{\safe@href@text}}%
       \@ifundefined{ead@text}{}{\let\prev@ead@text\ead@text}}}%                        
}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% normaltext, nohyphen, today

% normalus tekstas (justify)
\def\normaltext{\let\\=\@normalcr%
  \leftskip\z@ \@rightskip\z@ \rightskip\@rightskip%
  \parfillskip\@flushglue}

% skiemenavimo isjungimas
\def\nohyphen{\pretolerance=\@M \tolerance=\@M \hyphenpenalty=\@M \exhyphenpenalty=\@M}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% newpseudoenvironment
% \begin ... \end mechanizmo perrabibrezimas, kad 
% galima butu isvengti papildomu grupiu (ST)

% ar nera pakrautas sis macro?
\@ifundefined{org@begin}{
  \let\org@begin\begin
  \let\org@end\end}{}

  \def\begin#1{%
    \@ifundefined{pseudo@#1}%
      {\org@begin{#1}}{\csname pseudo@#1\endcsname[0]\relax}%
    }
  \def\end#1{%
    \@ifundefined{pseudo@#1}%
      {\org@end{#1}}{\csname pseudo@#1\endcsname[1]\relax}%
    }
  \def\newpseudoenvironment#1#2#3{%
    \expandafter\gdef\csname pseudo@#1\endcsname[##1]{%
       \relax\ifcase##1\relax\def\@@next@@{#2}\or\def\@@next@@{#3}\else\let\@@next@@\relax\fi\@@next@@}%
    }


%%%% end of vtexfmpdf

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% pakeitimai vtexfmpdf.sty:

\setattribute{email}{text}{E-mail:~}

%% Kai yra vienas adresas, email'ai isvedami su zymemis:
%% \author{\thanksref{e1}\ead[label[=e1,mark]{}}
%% \printead{e1} ->*foo@foo.com

\newcounter{emailref}

\setvaluelist{emailmarks}{*,**,\textdagger,\textdaggerdbl}

\def\theemailref{\getitemvalue{emailmarks}{\the\c@emailref}}

\define@key{ead}{mark}[true]{\usethankscounter{emailref}\thankslabel{\ead@label}}
%\define@key{ead}{mark}[true]{}

\def\@@printead[#1]#2{{%
   \if@printead@opt%[]
      \def\safe@href@text{#1}%
      \not@ead@starfalse%
   \fi%      
   \let\prev@ead@text\relax%
   \let\@ead@sep\relax%
   \let\ead@text\relax%
   \let\ead@prefix\relax%
   \def\ead@type{}%
   \@tempcnta=0%
   \let\sv@safe@href\safe@href%
   \printead@fmt{\@for\ead@ref:=#2\do{%
       \advance\@tempcnta by1%
       \let\safe@href\sv@safe@href%
       \@ead@sep\let\@ead@sep\ead@sep%
       \@ifundefined{r@\ead@ref @nopdflink}{}{\def\safe@href##1##2{##2}}%
       \@ifundefined{r@\ead@ref @email}{}{\let\ead@text\email@text\def\ead@type{email}\def\ead@prefix{mailto:}}%
       \@ifundefined{r@\ead@ref @url}{}{\let\ead@text\url@text\def\ead@type{url}\def\ead@prefix{http://}}%
       \@ifundefined{r@\ead@ref @fullurl}{}{\let\ead@text\fullurl@text\def\ead@type{fullurl}\def\ead@prefix{}}%
       \ifx\prev@ead@text\ead@text\let\ead@text\relax\fi%
       \if@printead@opt\ifnum\@tempcnta>1\@latex@error{Command \@backslashchar printead[]{e1} could have only one parameter "e1"!}\@eha\fi%
       \else\@ifundefined{r@\ead@ref @\ead@type text}{\def\safe@href@text{\@ifundefined{r@\ead@ref thanks}{}{\thanksref{\ead@ref}}\saferef{\ead@ref @\ead@type}}}{\def\safe@href@text{\@ifundefined{r@\ead@ref thanks}{}{\thanksref{\ead@ref}}\saferef{\ead@ref @\ead@type text}}}\fi%
       \ifnot@ead@star\ead@text\fi{\ead@size\def\null{}\safe@href{\ead@prefix\saferef{\ead@ref @\ead@type}}{\safe@href@text}}%
       \@ifundefined{ead@text}{}{\let\prev@ead@text\ead@text}}}%                        
}}



%%%%%%%%%%%%%%% Thanks
\def\atlthanks[#1]#2{\thankstext{#1}{#2}}

\def\artthanks[#1]#2{\thankstext{#1}{#2}}

\def\corthanks[#1]#2{\thankstext{#1}{#2}}

\def\thanks[#1]#2{\thankstext{#1}{#2}}

\let\atlthankstext\thankstext
\let\artthankstext\thankstext
\let\corthankstext\thankstext

%%%%%%%%%%%%%%% url package
\RequirePackage{url}
%\urlstyle{same}


%%%%%%%%%%%%%%% SECTIONS
\setcounter{secnumdepth}{5}
\newcounter {section}
\newcounter {subsection}[section]
\newcounter {subsubsection}[subsection]
\newcounter {paragraph}[subsubsection]
\newcounter {subparagraph}[paragraph]

\renewcommand\thesection      {\@arabic\c@section}
\renewcommand\thesubsection   {\thesection.\@arabic\c@subsection}
\renewcommand\thesubsubsection{\thesubsection .\@arabic\c@subsubsection}
\renewcommand\theparagraph    {\thesubsubsection.\@arabic\c@paragraph}
\renewcommand\thesubparagraph {\theparagraph.\@arabic\c@subparagraph}

\setcounter{tocdepth}{3}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% SECTION commands:
% from latex.ltx:
% Two improvements:
% 1. if section command is defined as "inline" the '.' will be inserted after heading;
% 2. section* will write to toc and will appear in pdf bookmarks

% dirty trick...
\def\@startsection#1#2#3#4#5#6{%
  \if@noskipsec \leavevmode \fi
  \par
  \@tempskipa #4\relax
  \@afterindenttrue
  \ifdim \@tempskipa <\z@
    \@tempskipa -\@tempskipa \@afterindentfalse
  \fi
  \if@nobreak
    \everypar{}%
  \else
    \addpenalty\@secpenalty\addvspace\@tempskipa
  \fi
  \@ifstar
    {\def\ssection@level{#2}\@ssect{#3}{#4}{#5}{#6}}%
    {\@dblarg{\@sect{#1}{#2}{#3}{#4}{#5}{#6}}}}

% Trick for the hyperref:
\def\setaftersec@dot#1{\if@autosecdot\setbox0=\hbox{#1}\ifdim\wd0>0\p@\def\aftersec@dot{.}\else\def\aftersec@dot{}\fi\fi}
\let\aftersec@dot\relax

% section - will add hook for the dot after section heading
\def\@sect#1#2#3#4#5#6[#7]#8{%
  \ifnum #2>\c@secnumdepth
    \let\@svsec\@empty
  \else
    \refstepcounter{#1}%
    \protected@edef\@svsec{\@seccntformat{#1}\relax}%
  \fi
  \@tempskipa #5\relax
  \ifdim \@tempskipa>\z@
    \begingroup
      #6{%
        \@hangfrom{\hskip #3\relax\@svsec}%
          \interlinepenalty \@M #8\@@par}%
    \endgroup
    \csname #1mark\endcsname{#7}%
    \addcontentsline{toc}{#1}{%
      \ifnum #2>\c@secnumdepth \else
        \protect\numberline{\csname the#1\endcsname}%
      \fi
      #7}%
  \else
    \setaftersec@dot{#8}%
    \def\@svsechd{%
      #6{\hskip #3\relax
      \@svsec #8\aftersec@dot}%
      \csname #1mark\endcsname{#7}%
      \addcontentsline{toc}{#1}{%
        \ifnum #2>\c@secnumdepth \else
          \protect\numberline{\csname the#1\endcsname}%
        \fi
        #7}}%
  \fi
  \@xsect{#5}}

% section* - will add hook for the dot after section heading and \contentsline 
\def\@ssect#1#2#3#4#5{%
  \@tempskipa #3\relax
  \ifdim \@tempskipa>\z@
    \begingroup
      #4{%
        \@hangfrom{\hskip #1}%
          \interlinepenalty \@M #5\@@par}%
    \endgroup
  \else
    \setaftersec@dot{#5}%
    \def\@svsechd{#4{\hskip #1\relax #5\aftersec@dot}}%
  \fi
  \ifnum\ssection@level=1\phantomsection\addcontentsline{toc}{section}{#5}\fi%
  \@xsect{#3}}

% Block adding to contents for the next command only:
\def\nocontentsline{%
  \let\@@addcontentsline\addcontentsline%
  \def\addcontentsline##1##2##3{\let\addcontentsline\@@addcontentsline}}

% \phantomsection is defined in hyperref
\let\phantomsection\relax




% LISTS
%%%% start of vtexlst.sty [2002/02/09 VTEX list type environments (VS)]

%%%%%%%%%%%%%% Hooks
% general list indent
\def\list@parindent{10\p@}

% enumerate
\def\enumerate@indent{\z@}
\def\enumerate@parindent{\list@parindent}
\def\enumerate@labelsep{.5em}
\def\enumerate@firsttopsep{\smallskipamount}
\def\enumerate@topsep{\z@}
\def\enumerate@rightskip{\z@}% {\z@ plus 1fill}
\let\enumerate@hook\relax

% longlist
\def\longlist@indent{\list@parindent}
\def\longlist@parindent{\list@parindent}
\def\longlist@labelsep{.5em}
\def\longlist@topsep{\smallskipamount}
\def\longlist@rightskip{\z@}% {\z@ plus 1fill}
\let\longlist@hook\relax

% itemize
\def\itemize@indent{\z@}
\def\itemize@parindent{\list@parindent}
\def\itemize@labelsep{.5em}
\def\itemize@firsttopsep{\smallskipamount}
\def\itemize@topsep{\z@}
\def\itemize@rightskip{\z@}% {\z@ plus 1fill}
\let\itemize@hook\relax

% description
\def\description@indent{\list@parindent}
\let\description@topsep\smallskipamount
\let\description@hook\relax

% quotation
\let\quotation@size\relax
\def\quotation@itemindent{\z@}
\def\quotation@parindent{\list@parindent}
\def\quotation@leftmargin{2pc}
\let\quotation@rightmargin\z@
\let\quotation@topsep\smallskipamount


% quote
\let\quote@size\relax
\def\quote@indent{\z@}
\def\quote@leftmargin{2pc}
\def\quote@rightmargin{2pc}
\let\quote@topsep\smallskipamount
\def\source#1{\hfill\par\hfill #1\par}

% verse
\def\verse@margin{2pc}
\let\verse@topsep\smallskipamount


%%%%%%%%%%%%%% Parameters
\@lowpenalty   51
\@medpenalty  151
\@highpenalty 301
\@beginparpenalty -\@lowpenalty
\@endparpenalty   -\@lowpenalty
\@itempenalty     -\@lowpenalty


%%%%%%%%%%%%%% General list parameters (not important}

\parsep\z@
\topsep\z@
\partopsep\z@
\itemsep\z@
\labelsep.5em

\def\@listi  {\leftmargin\leftmargini}

\def\@listii {\leftmargin\leftmarginii%
             \labelwidth\leftmarginii%
             \advance\labelwidth-\labelsep}%

\def\@listiii{\leftmargin\leftmarginiii
              \labelwidth\leftmarginiii
              \advance\labelwidth-\labelsep}

\def\@listiv {\leftmargin\leftmarginiv
              \labelwidth\leftmarginiv
              \advance\labelwidth-\labelsep}

\def\@listvi {\leftmargin\leftmarginvi
              \labelwidth\leftmarginvi
              \advance\labelwidth-\labelsep}

\setlength\leftmargini   {2em}
\setlength\leftmarginii  {2.2em}
\setlength\leftmarginiii {1.87em}
\setlength\leftmarginiv  {1.7em}
\setlength\leftmarginv   {1em}
\setlength\leftmarginvi  {1em}

\@listi

\setlength  \labelwidth{\leftmargini}
\addtolength\labelwidth{-\labelsep}

%%%%%%%%%%%%%% Enumerate

\def\theenumi  {\@arabic\c@enumi}
\def\theenumii {\@alph\c@enumii}
\def\theenumiii{\@roman\c@enumiii}
\def\theenumiv {\@Alph\c@enumiv}

\def\labelenumi  {\theenumi.}
\def\labelenumii {\theenumii)}
\def\labelenumiii{\theenumiii.}
\def\labelenumiv {\theenumiv.}

\def\enumerate{\@ifnextchar[{\@enumerate}{\@enumerate[]}}

\def\@enumerate[#1]{%
    \ifnum \@enumdepth >\thr@@ \@toodeep\else
    \advance\@enumdepth \@ne 
    \edef\@enumctr{enum\romannumeral\the\@enumdepth}%
    \list {\csname label\@enumctr\endcsname}%
       {\usecounter{\@enumctr}
        \def\makelabel##1{{\hfill\normalfont ##1}}
%
        \ifx.#1.%
           \setcounter{\@enumctr}{3}% 
           \expandafter\settowidth\expandafter\labelwidth\expandafter{\csname label\@enumctr\endcsname}%
           \setcounter{\@enumctr}{0}%
        \else%
           \settowidth{\labelwidth}{#1}
        \fi%
        \labelsep=\enumerate@labelsep%
        \itemindent=\labelwidth \advance\itemindent\labelsep%
        \ifnum \@enumdepth=1\advance\itemindent by\enumerate@indent\fi%
        \leftmargin=\the\itemindent%
        \itemindent\z@%
        \partopsep\z@  \parsep\z@ \itemsep\z@ \rightmargin\z@
        \ifnum \@enumdepth=1 \topsep\enumerate@firsttopsep \else \topsep\enumerate@topsep\fi%
        \listparindent\enumerate@parindent%        
        \@rightskip\enumerate@rightskip%
        \enumerate@hook% 
        }\fi}

\let\endenumerate =\endlist

%%%%%%%%%%%%%% Longlist

\newcounter{longlist}
\def\thelonglist   {\@roman\c@longlist}
\def\labellonglist {\thelonglist)}

\def\longlist{\@ifnextchar[{\@longlist}{\@longlist[]}}

\def\@longlist[#1]{%
    \list {\labellonglist}%
       {\usecounter{longlist}
        \def\makelabel##1{{\hfill\normalfont ##1}}
%
        \ifx.#1.%
           \setcounter{longlist}{3}% 
           \settowidth\labelwidth{\labellonglist}%
           \setcounter{longlist}{0}%
        \else%
           \settowidth{\labelwidth}{#1}
        \fi%
        \labelsep=\longlist@labelsep%
        \itemindent=\labelwidth \advance\itemindent\labelsep%
        \advance\itemindent by\longlist@indent%
        \rightmargin\z@ \leftmargin\z@%
        \partopsep\z@  \parsep\z@ \itemsep\z@ %
        \topsep\longlist@topsep%
        \listparindent\longlist@parindent%        
        \@rightskip\longlist@rightskip%
        \longlist@hook% 
        }}

\let\endlonglist =\endlist


%%%%%%%%%%%%%%  setenumtype

\def\setenumtype#1{%
\if#1a \let\enumerate\longlist\fi%
\if#1c \def\enumerate@indent{\z@}\fi}%

%%%%%%%%%%%%%%  itemize

\def\labelitemi  {\textbullet}
\def\labelitemii {\textendash}
\def\labelitemiii{\textasteriskcentered} 
\def\labelitemiv {{\footnotesize +}}

\def\itemize{\@ifnextchar[{\@itemize}{\@itemize[]}}

\def\@itemize[#1]{%
    \ifnum \@itemdepth >\thr@@ \@toodeep\else
    \advance\@itemdepth \@ne 
    \edef\@itemitem{labelitem\romannumeral\the\@itemdepth}%
    \list {\csname\@itemitem\endcsname}%
       {\def\makelabel##1{{\hfill\normalfont ##1}}        
%
        \ifx.#1.%
           \settowidth\labelwidth{\csname\@itemitem\endcsname}%
        \else%
           \settowidth{\labelwidth}{#1}
        \fi%
        \labelsep=\itemize@labelsep%
        \itemindent=\labelwidth \advance\itemindent\labelsep%
        \ifnum \@itemdepth=1\advance\itemindent by\itemize@indent\fi%
        \leftmargin=\the\itemindent%
        \itemindent\z@%
        \partopsep\z@  \parsep\z@ \itemsep\z@ \rightmargin\z@
        \ifnum \@itemdepth=1 \topsep\itemize@firsttopsep \else \topsep\itemize@topsep\fi%
        \listparindent\itemize@parindent%        
        \@rightskip\itemize@rightskip%
        \itemize@hook% 
        }\fi}

\let\enditemize =\endlist

%%%%%%%%%%%%%%  description

\def\description{%
         \list{}{\labelwidth\z@ \labelsep\z@  \rightmargin\z@
         \leftmargin\z@ \advance\leftmargin by\description@indent
         \itemindent-\description@indent
         \partopsep\z@ \topsep\description@topsep \parsep\z@
         \itemsep\z@ \listparindent\z@
         \description@hook%
         \let\makelabel\descriptionlabel}}

\def\enddescription{\endlist}

\def\descriptionlabel#1{\if.#1.\else\bfseries #1\hskip.5em\fi}

%%%%%%%%%%%%%%  quotation

\def\quotation{%
        \list{}{\quotation@size%
        \listparindent\quotation@parindent%
        \itemindent   \quotation@itemindent%
        \rightmargin\quotation@rightmargin   \leftmargin\quotation@leftmargin%
        \partopsep\z@ \topsep\quotation@topsep \parsep\z@%
                        }%
        \item[\Q@strut]\relax}

\def\endquotation{\endlist}

\def\Q@strut{\leavevmode\hbox{\vrule height9pt depth1pt width0pt}}

%%%%%%%%%%%%%%  quote

\def\quote{%
        \list{}{\quote@size%
        \listparindent\quote@indent%
        \itemindent \listparindent%
        \rightmargin\quote@rightmargin   \leftmargin\quote@leftmargin%
        \partopsep\z@ \topsep\quote@topsep \parsep\z@%
                       }%
        \item\relax}

\def\endquote{\endlist}

%%%%%%%%%%%%%%  verse


\def\verse{%
   \let\\\@centercr
   \list{}{\itemindent\z@ \listparindent\z@ \rightmargin\verse@margin \leftmargin\rightmargin
	   \partopsep\z@ \parsep\z@ \topsep\verse@topsep \itemsep\z@}%
   \item\relax}

\def\endverse{\endlist}

%%%% end   of vtexlst.sty


%%%%%% changes to vtexlst.sty:

% enumerate
\def\enumerate@indent{\list@parindent}

% itemize
\def\itemize@indent{\list@parindent}

% longlist
\def\list@parindent{10\p@}
\renewcommand\labellonglist {(\thelonglist)}

% quotation
\def\quotation@leftmargin{1pc}
\def\quotation@rightmargin{1pc}

% quote
\def\quote@leftmargin{1pc}
\def\quote@rightmargin{1pc}

% SECTIONS
%\RequirePackage[normalssect]{vtexsec}

% MATH
%%%% start of vtexmth.sty [2003/05/08 VTEX math settings (VS)]
%%%%%%%%%%%%%% Parameters
\setlength\arraycolsep   {1.2\p@}
\setlength\tabcolsep     {6\p@}
\setlength\arrayrulewidth{.4\p@}
\setlength\doublerulesep {2\p@}
\setlength\tabbingsep    {6\p@}
\setlength\jot           {6\p@}


%%%%%%%%%%%%%% Math spacing
\setlength\thinmuskip  {2.5mu}
\setlength\medmuskip   {3.5mu plus 1.5mu minus 2mu}
\setlength\thickmuskip {3.75mu plus 1.5mu}
\setlength\mathsurround{0.1\p@}

%%%%%%%%%%%%%% Equation numbering

\ifcase\eqn@numbering
   \renewcommand\theequation{\@arabic\c@equation}
\or %seceqn  
  \@addtoreset {equation}{section}
  \renewcommand\theequation{\thesection.\@arabic\c@equation}
\or %chapeqn
  \@addtoreset {equation}{chapter}
  \renewcommand\theequation{\thechapter.\@arabic\c@equation}
\fi

%%%%%%%%%%%%%% tfrac, dfrac, dvt, dvtx

\def\tfrac#1#2{{\textstyle\frac{#1}{#2}}}
\def\dfrac#1#2{{\displaystyle\frac{#1}{#2}}}

\def\dvt{\colon\ }

\def\dvtx{%
  \mathchoice{\nobreak\,\colon\relax}%
             {\nobreak\,\colon\relax}%
             {\nobreak\,\colon\;\relax}%
             {\nobreak\,\colon\;\relax}%
  }


%%%%%%%%%%%%%% tsub, textsubscript, tsup, textsuperscript

\let\textsuperscript\relax
\DeclareRobustCommand*\textsuperscript[1]{%
  \@textsuperscript{\selectfont#1}}
\def\@textsuperscript#1{%
  {\m@th\ensuremath{^{\mathchoice{\mbox{\fontsize\f@size\z@#1}}%
                                 {\mbox{\fontsize\tf@size\z@#1}}%
                                 {\mbox{\fontsize\sf@size\z@#1}}%
                                 {\mbox{\fontsize\ssf@size\z@#1}}%
                     }%
                   }%
  }%
}

\DeclareRobustCommand*\textsubscript[1]{%
  \@textsubscript{\selectfont#1}}
\def\@textsubscript#1{%
  {\m@th\ensuremath{_{\mathchoice{\mbox{\fontsize\f@size\z@#1}}%
                                 {\mbox{\fontsize\tf@size\z@#1}}%
                                 {\mbox{\fontsize\sf@size\z@#1}}%
                                 {\mbox{\fontsize\ssf@size\z@#1}}%
                     }%
                   }%
  }%
}


\let\tsub\textsubscript
\let\tsup\textsuperscript

%%%%%%%%%%%%%% big, bigg

\newcommand{\m@kebig}[3]{\hbox{#1$\left#2\vbox to #3ex{}\right.\n@space$}}
\newcommand{\m@kelarge}[2]{\mathchoice{\m@kebig{}{#1}{#2}}{\m@kebig{}{#1}{#2}}
    {\m@kebig\scriptsize{#1}{#2}}{\m@kebig\tiny{#1}{#2}}}
\renewcommand{\big}[1]{{\m@kelarge{#1}{1.79999}}}
\renewcommand{\Big}[1]{{\m@kelarge{#1}{2.43529}}}
\renewcommand{\bigg}[1]{{\m@kelarge{#1}{3.07059}}}
\renewcommand{\Bigg}[1]{{\m@kelarge{#1}{3.70588}}}

%%%%%%%%%%%%%% divid, zs

\def\divid#1#2{%
  \mathchoice{{#1}\over{#2}}% Display mode
    {\vbox{\hbox{$\scriptstyle #1$}\vskip1pt}\over
       \vbox{\vskip1pt\hbox{$\scriptstyle #2$}\vskip1pt}}% Text mode
    {\vbox{\hbox{$\scriptstyle #1$}\vskip1pt}\over
       \vbox{\vskip2pt\hbox{$\scriptstyle #2$}\vskip1pt}}% Script mode
    {\vbox{\hbox{$\scriptstyle #1$}\vskip1pt}\over
       \vbox{\vskip.7pt\hbox{$\scriptstyle #2$}\vskip3pt}}% Sriptsript mode
 }
% ZS apibrezimas
\def\zs#1{\mathchoice{#1}{#1}{\lower.4ex\hbox{$\scriptstyle#1$}}
   {\lower0.4ex\hbox{$\scriptscriptstyle#1$}}}
\def\zss#1{\mathchoice{#1}{#1}{\lower.8ex\hbox{$\scriptstyle#1$}}
   {\lower0.8ex\hbox{$\scriptscriptstyle#1$}}}

%%%%%%%%%%%%%% operatorname
\def\operatorname#1{\mathop{\mathrm{#1}}\nolimits}

%%%%%%%%%%%%%% bolds

\DeclareRobustCommand{\bolds}[1]{%
  \begingroup
  \let\@nomath\@gobble \mathversion{bold}%
  \math@atom{#1}{%
  \mathchoice%
    {\hbox{$\m@th\displaystyle#1$}}%
    {\hbox{$\m@th\textstyle#1$}}%
    {\hbox{$\m@th\scriptstyle#1$}}%
    {\hbox{$\m@th\scriptscriptstyle#1$}}}%
  \endgroup}

\def\math@atom#1#2{%
   \binrel@{#1}\binrel@@{#2}}

\def\binrel@#1{\begingroup
  \setbox\z@\hbox{\thinmuskip0mu
    \medmuskip\m@ne mu\thickmuskip\@ne mu
    \setbox\tw@\hbox{$#1\m@th$}\kern-\wd\tw@
    ${}#1{}\m@th$}%
  \edef\@tempa{\endgroup\let\noexpand\binrel@@
    \ifdim\wd\z@<\z@ \mathbin
    \else\ifdim\wd\z@>\z@ \mathrel
    \else \relax\fi\fi}%
  \@tempa
  }
\let\binrel@@\relax
\let\boldsymbol\bolds

%%%%%%%%%%%%%% tabular

\def\ccline#1{\do@ccline(#1,1-0)}
\def\do@ccline(#1-#2,#3){%
  \noalign{\ifnum#1>#2\gdef\temp@next{}\else\gdef\temp@next{\@cline#1-#2\@nil\do@ccline(#3,1-0)}\fi}%
  \temp@next
  }


%%%%%%%%%%%%%% aligned

\newenvironment{aligned}{%
  \relax\ifmmode\else{\@latex@error{aligned aplinka naudojama tik matematinej modoje!}\@ehc}\fi
  \intertext@\null\@ifnextchar[{\aligned@}{\aligned@[c]}%
  }{\crcr\egroup\egroup}

\def\aligned@[#1]{%
  \if #1t\vtop \else \if#1b\vbox \else \vcenter \fi\fi
  \bgroup
   \let\\\c@eqncr
   \ialign\bgroup\hfil\strut$\m@th\displaystyle{##{}}$&&%
    $\m@th\displaystyle{{}##{}}$\hfil\crcr}

\def\c@eqncr{%
  {\ifnum0=`}\fi
   \@ifstar{\global\@eqpen\@M\c@yeqncr
     }{\global\@eqpen\interdisplaylinepenalty \c@yeqncr}%
  }

\def\c@yeqncr{\@testopt\c@xeqncr\z@skip}
\def\c@xeqncr[#1]{%
  \ifnum0=`{\fi}%
  \cr\noalign{\penalty\@eqpen\vskip\jot\vskip #1\relax}%
  }

\def\intertext{\ClassError{fied}{Invalid use of \string\intertext}\@eha}
\def\intertext@{\def\intertext##1{\noalign{%
  \penalty\postdisplaypenalty\vskip\belowdisplayskip
  \vbox{\normalbaselines\noindent##1}%
  \penalty\predisplaypenalty\vskip\abovedisplayskip\vskip\jot}}}



%%%% end   of vtexmth.sty

% triukas ikisti teksta i numeri:
\def\eqntext#1{\global\let\curr@eqnnum\@eqnnum\gdef\@eqnnum##1##2{$#1$\global\let\@eqnnum\curr@eqnnum}}

% THEOREMS
%%%% start of vtexthm.sty [2001/11/24 VTEX theorem type environments (VS)]

%%%%%%%%%%%%%% HOOKS
  \newskip\theorempreskipamount
  \newskip\theorempostskipamount
  \global\setlength\theorempreskipamount{12\p@ \@plus 2\p@ \@minus 1\p@}
  \global\setlength\theorempostskipamount{12\p@ \@plus 2\p@ \@minus 1\p@}
  \let\thm@indent\z@%
  \def\@thmcounter#1{\noexpand\arabic{#1}}

  \gdef\thmcounter@sep{.} % taskas po teoremos skaitliuko
  \gdef\xxthmcounter@sep{.} % taskas po teoremos skaitliuko xxtheorem atveju

  \let\thm@skip\enskip   % tarpas nuo teoremos iki teksto

% Proof:
  \def\proofname{Proof}
  \def\proof@sep{.}
  \let\proof@shape\scshape
  \let\proof@skip\enskip
  \let\proof@indent\noindent

% NEWTHEOREM and PROCLAIM environments 
%
\gdef\theoremstyle#1{%
   \@ifundefined{th@#1}{\@warning{Unknown theoremstyle `#1'. Using `plaindot'}%
          \theorem@style{plaindot}}%
      {\theorem@style{#1}}%
      \begingroup
        \csname th@\the\theorem@style \endcsname
      \endgroup}

\newtoks\theorem@style
\global\theorem@style{plaindot}

\gdef\@xnthm#1#2[#3]{\expandafter\@ifdefinable\csname #1\endcsname
   {%
    \@definecounter{#1}\@addtoreset{#1}{#3}%
    \expandafter\xdef\csname the#1\endcsname
      {\expandafter \noexpand \csname the#3\endcsname
       \thmcounter@sep \@thmcounter{#1}}%
    \def\@tempa{\global\@namedef{#1}}%
    \expandafter \@tempa \expandafter{%
      \csname th@\the \theorem@style \endcsname
     \@thm{#1}{#2}}%
    \global \expandafter \let \csname end#1\endcsname \@endtheorem
    \def\@tempb{\global\@namedef{#1*}}%
    \expandafter \@tempb \expandafter{%
      \csname th@\the \theorem@style \endcsname
     \@thmstar{#2}}%
    \global \expandafter \let \csname end#1*\endcsname \@endtheorem
   }}

\gdef\@ynthm#1#2{\expandafter\@ifdefinable\csname #1\endcsname
   {\@definecounter{#1}%
    \expandafter\xdef\csname the#1\endcsname{\@thmcounter{#1}}%
    \def\@tempa{\global\@namedef{#1}}\expandafter \@tempa
     \expandafter{\csname th@\the \theorem@style \endcsname
    \@thm{#1}{#2}}%
    \global \expandafter \let \csname end#1\endcsname \@endtheorem
    \def\@tempb{\global\@namedef{#1*}}\expandafter \@tempb
     \expandafter{\csname th@\the \theorem@style \endcsname
    \@thmstar{#2}}%
    \global \expandafter \let \csname end#1*\endcsname \@endtheorem}}

\gdef\@othm#1[#2]#3{\expandafter\@ifdefinable\csname #1\endcsname
  {\expandafter \xdef \csname the#1\endcsname
     {\expandafter \noexpand \csname the#2\endcsname}%
    \def\@tempa{\global\@namedef{#1}}\expandafter \@tempa
     \expandafter{\csname th@\the \theorem@style \endcsname
    \@thm{#2}{#3}}%
    \global \expandafter \let \csname end#1\endcsname \@endtheorem
    \def\@tempb{\global\@namedef{#1*}}\expandafter \@tempb
     \expandafter{\csname th@\the \theorem@style \endcsname
    \@thmstar{#3}}%
    \global \expandafter \let \csname end#1*\endcsname \@endtheorem}}

\gdef\@thm#1#2{\refstepcounter{#1}%
   \trivlist
   \itemindent\thm@indent%
   \@topsep \theorempreskipamount%
   \@topsepadd \theorempostskipamount%
   \@ifnextchar [%
   {\@ythm{#1}{#2}}%
   {\@begintheorem{#2}{\csname the#1\endcsname}\ignorespaces}}

\gdef\@thmstar#1{%
   \trivlist
   \itemindent\thm@indent%
   \@topsep \theorempreskipamount%
   \@topsepadd \theorempostskipamount%
   \@ifnextchar [%
   {\@ythmstar{#1}}%
   {\@@begintheorem{#1}\ignorespaces}}

\def\@ythmstar#1[#2]{%
  \@@opargbegintheorem{#1}{#2}\ignorespaces}

\global\let\@xthm\relax

\if@xx@theorem
  \def\fmt@thm@name#1#2{#2\xxthmcounter@sep\ #1}
\else
  \def\fmt@thm@name#1#2{#1\ #2}
\fi

\def\theorem@@shape#1#2#3{\expandafter\def\csname th@#1@#2@shape\endcsname{#3}}
\let\theoremshape\theorem@@shape

\theorem@@shape{plaindot}{head}{\normalfont\scshape}
\theorem@@shape{plaindot}{optional}{\mdseries\upshape}
\theorem@@shape{plaindot}{body}{\normalfont\itshape}

\theorem@@shape{proclaim}{head}{\normalfont\scshape}
\theorem@@shape{proclaim}{optional}{\normalfont}
\theorem@@shape{proclaim}{body}{\normalfont\upshape}


\gdef\th@plaindot{%
  \let\th@main@head@shape\th@plaindot@head@shape
  \let\th@main@optional@shape\th@plaindot@optional@shape
  \let\th@main@body@shape\th@plaindot@body@shape
  \th@main@theorem
}

\gdef\th@proclaim{%
  \let\th@main@head@shape\th@proclaim@head@shape
  \let\th@main@optional@shape\th@proclaim@optional@shape
  \let\th@main@body@shape\th@proclaim@body@shape
  \th@main@theorem
}

\gdef\th@main@theorem{\th@main@body@shape
  \def\@begintheorem##1##2{%
        \item\relax{\normalfont\th@main@head@shape\fmt@thm@name{##1}{##2}\thmcounter@sep}\thm@skip}%
  \def\@@begintheorem##1{%
        \item\relax{\normalfont\th@main@head@shape ##1\thmcounter@sep}\thm@skip}%
\def\@opargbegintheorem##1##2##3{%
   \item\relax{\normalfont\th@main@head@shape\fmt@thm@name{##1}{##2}}\ {\th@main@optional@shape ##3\thmcounter@sep}\thm@skip}%
\def\@@opargbegintheorem##1##2{%
   \item\relax{\normalfont\th@main@head@shape ##1}\ {\th@main@optional@shape ##2\thmcounter@sep}\thm@skip}}

\let\old@newtheorem\newtheorem
\def\newtheorem{\theoremstyle{plaindot}\old@newtheorem}
\def\newproclaim{\theoremstyle{proclaim}\old@newtheorem}

\ifcase\thm@numbering
   \newtheorem{thm}{Theorem}
   \def\thethm{\@arabic\c@thm}
\or % secthm
  \newtheorem{thm}{Theorem}[section]
  \@addtoreset{thm}{section}
  \def\thethm{\thesection.\@arabic\c@thm}
\or % chapthm
  \newtheorem{thm}{Theorem}[chapter]
  \@addtoreset{thm}{chapter}
  \def\thethm{\thechapter.\@arabic\c@thm}
\fi

\g@addto@macro\@endtheorem{\@endpefalse}

% PROOF ENVIRONMENT

\def\theqed{\ensuremath{\square}}

\gdef\qed{\relax\ifmmode~\hfill\theqed\else\unskip\nobreak~\hfill\theqed\fi}
\let\@qed\qed

\gdef\qedbreak{\par\nobreak\parfillskip0pt\hfill}

\gdef\upqed{\vskip-\belowdisplayskip\vskip-\baselineskip\kern0pt}

\def\noqed{\let\sv@qed\@qed\def\@qed{\global\let\@qed\sv@qed}}

\newenvironment{pf}%
  {\par\addvspace{\theorempreskipamount}\proof@indent
   {\proof@shape\proofname\proof@sep}\proof@skip\ignorespaces}%
   {\@qed\par\addvspace{\theorempreskipamount}}

\@namedef{pf*}#1{\par\begingroup\def\proofname{#1}\pf\endgroup\ignorespaces}
\@namedef{endpf*}{\@qed\par\addvspace{\theorempostskipamount}}

%%%% end   of vtexthm.sty

\theoremshape{plaindot}{head}{\normalfont\bfseries}
\theoremshape{plaindot}{optional}{\upshape\bfseries}
\theoremshape{plaindot}{body}{\normalfont\itshape}

\theoremshape{proclaim}{head}{\normalfont\fontseries{bx}\itshape\selectfont}
\theoremshape{proclaim}{optional}{\fontseries{bx}\itshape\selectfont}
\theoremshape{proclaim}{body}{\normalfont\itshape}

%% For newremark:
\gdef\th@remark{%
  \let\th@main@head@shape\th@remark@head@shape
  \let\th@main@optional@shape\th@remark@optional@shape
  \let\th@main@body@shape\th@remark@body@shape
  \th@main@theorem}

  \theoremshape{remark}{head}{\normalfont\fontseries{bx}\itshape\selectfont}
  \theoremshape{remark}{optional}{\fontseries{bx}\itshape\selectfont}
  \theoremshape{remark}{body}{\normalfont\upshape}

\def\newremark{\theoremstyle{remark}\old@newtheorem}

% Proof

\let\proof@shape\bfseries

% BIBLIOGRAPHY
  \def\thebibliography{}
  \def\newblock{\hskip .11em\@plus.33em\@minus.07em}

  \if@nameyear
      \RequirePackage[comma]{natbib}
  \else
    \RequirePackage[square,comma,numbers,openbib,sort&compress]{natbib}
    \newlength{\bibindent}
    \setlength{\bibindent}{18pt}
    \let\cite\citep
  \fi

   \let\bibfont\small
   \def\authors#1{#1}

\newenvironment{bibtext}{\endgraf}{\endgraf}

%% Load hyperref:

\if@loadhyperref
  \AtEndOfClass{\RequirePackage[dvips]{hyperref}}
  \IfFileExists{hypernat.sty}{\RequirePackage{hypernat}}{}


\fi

% arXiv hyperref versija sena, nepalaiko \texttildelow
\DeclareTextSymbol{\texttildelow}{OT1}{126}


% FLOATS

%%%% start of vtexfltpdf.sty [2005/04/15 VTEX float type environments (VS)]

%%%%%%%%%%%%%% HOOKS
\def\figurename{Figure}
\def\tablename {Table}

% Figure
\let\figurefloat@shape\centering
\def\figurecaption@size{\footnotesize}
\def\figurecaption@skip{8\p@}
\def\figurename@skip{\hskip.5em}
\let\figurename@size\relax

% Table
\let\starttable@hook\relax
\let\tablefloat@shape\centering
\let\table@size\footnotesize
\def\tablecaption@shape{\centering}%
\def\tablecaption@size{\footnotesize}
\def\tablecaption@skip{4\p@}
\def\tablename@skip{\hskip.5em}
\let\tablename@size\relax

% Tabnote
\def\firsttabnote@skip{\vskip4\p@}
\def\tabnote@skip{\lineskip2\p@}
\let\tabnote@size\footnotesize
\let\tabnote@indent\leavevmode

% Contcaption
\let\contcaption@shape\textit

%%%%%%%%%%%%%% FLOAT PARAMETERS

\setlength\floatsep       {18\p@ \@plus 6\p@ \@minus 2\p@}
\setlength\textfloatsep   {18\p@ \@plus 6\p@ \@minus 2\p@}
\setlength\intextsep      {18\p@ \@plus 6\p@ \@minus 2\p@}
\setlength\dblfloatsep    {18\p@ \@plus 6\p@ \@minus 2\p@}
\setlength\dbltextfloatsep{24\p@ \@plus 6\p@ \@minus 2\p@}

%  For floats on a separate float page or column:
\setlength\@fptop   {0\p@ \@plus 1fil}
\setlength\@fpsep   {8\p@ \@plus 1000fil}
\setlength\@fpbot   {0\p@ \@plus 1fil}
\setlength\@dblfptop{0\p@ \@plus 1fil}
\setlength\@dblfpsep{8\p@ \@plus 1000fil}
\setlength\@dblfpbot{0\p@ \@plus 1fil}

%  Float counters:
\setcounter{topnumber}{5}
\renewcommand\topfraction{.99}
\setcounter{bottomnumber}{5}
\renewcommand\bottomfraction{.99}
\setcounter{totalnumber}{10}
\renewcommand\textfraction{.05}
\renewcommand\floatpagefraction{.9}
\setcounter{dbltopnumber}{5}
\renewcommand\dbltopfraction{.99}
\renewcommand\dblfloatpagefraction{.8}


%%%%%%%%%%%%%%  FIGURES

\newcount\c@figure
\let\cl@figure\@empty
\let\p@figure\@empty

\ifcase\float@numbering
   \def\thefigure{\@arabic\c@figure}
\or %secfloat
   \@addtoreset{figure}{section}
   \def\thefigure{\thesection.\@arabic\c@figure}
\or %chapfloat
   \@addtoreset{figure}{chapter}
   \def\thefigure{\thechapter.\@arabic\c@figure} 
\fi

\def\fps@figure{tbp}
\def\ftype@figure{1}
\def\ext@figure{lof}
\def\fnum@figure{\figurename~\thefigure.}

\def\figure{\let\@makecaption\@makefigurecaption%
            \let\@floatboxreset\figure@boxreset%
            \@float{figure}}

\def\endfigure{\end@float}

\@namedef{figure*}{\let\@makecaption\@makefigurecaption%
                   \let\@floatboxreset\figure@boxreset%
                   \@dblfloat{figure}}

\@namedef{endfigure*}{\end@dblfloat}

\def\figure@boxreset {%
        \reset@font
        \normalsize
        \@setminipage
        \figurefloat@shape}

\long\def\@makefigurecaption#1#2{%
  \vskip\figurecaption@skip%
  \figurecaption@size%
  \setbox\@tempboxa\hbox{{\figurename@size #1}\figurename@skip%
  \if@contcaption\contcaptionbraces@left\contcaption@shape{#2}\contcaptionbraces@right\else #2\fi}%
  \ifdim \wd\@tempboxa >\hsize%
    \unhbox\@tempboxa\par%
  \else%
     \figurecaption@fmt{\box\@tempboxa}\par%
  \fi}

\def\figurecaption@fmt#1{\hbox to\hsize{\hfill#1\hfill}}

%%%%%%%%%%%%%% Cont Figure
\newenvironment{contfigure}{%
    \let\@makecaption\@makefigurecaption%
    \let\@floatboxreset\figure@boxreset%
    \@float{figure}}
    {\end@float}
\newenvironment{contfigure*}{%
    \let\@makecaption\@makefigurecaption
    \let\@floatboxreset\figure@boxreset%
    \@dblfloat{figure}}
    {\end@dblfloat}

\newenvironment{sidewayscontfigure}{%
  \let\@makecaption\@makefigurecaption%
  \let\@floatboxreset\figure@boxreset%
  \@rotfloat{figure}}
  {\end@rotfloat}

%%%%%%%%%%%%%% Float
\newenvironment{float}[1]{\expandafter\global\expandafter\let\expandafter\endfloat
  \csname end#1\endcsname\csname #1\endcsname}{\endfloat}


%%%%%%%%%%%%%%  TABLES

\newcount\c@table
\let\cl@table\@empty
\let\p@table\@empty

\ifcase\float@numbering
    \def\thetable{\@arabic\c@table}
\or %secfloat
  \@addtoreset{table}{section}
  \def\thetable{\thesection.\@arabic\c@table}
\or %chapfloat
  \@addtoreset{table}{chapter}
  \def\thetable{\thechapter.\@arabic\c@table}
\fi

\def\fps@table{tbp}
\def\ftype@table{2}
\def\ext@table{lot}
\def\fnum@table{\tablename~\thetable.}

\def\table{\let\@makecaption\@maketablecaption\starttable@hook%
           \tablewidth\hsize%
           \let\@floatboxreset\table@boxreset\@float{table}}

\def\endtable{\end@float}

\@namedef{table*}{\let\@makecaption\@maketablecaption\starttable@hook%
                  \tablewidth\textwidth%
                  \let\@floatboxreset\table@boxreset\@dblfloat{table}}

\@namedef{endtable*}{\end@dblfloat}

\def\table@boxreset{%
        \reset@font%
        \tablefloat@shape%
        \table@size%
        \@setnobreak%
        \@setminipage%
        \setcounter{tabnote}{0}}

\newdimen\tablewidth \tablewidth\textwidth

\long\def\@maketablecaption#1#2{%
    \tablecaption@shape%
    \parbox[t]{\tablewidth}{\tablecaption@size{\tablename@size #1}\tablename@skip%
    \if@contcaption\contcaptionbraces@left\contcaption@shape{#2}\contcaptionbraces@right\else #2\fi\par}%
    \vskip\tablecaption@skip}

%%%%%%%%%%%%%% Continued Table
\newtoks\table@head

\long\def\thead#1\endthead{\global\table@head{#1}#1}
\def\contthead{\the\table@head}

\let\contpart\relax

\newenvironment{conttable}{\let\@makecaption\@maketablecaption\starttable@hook%
  \let\footnoterule\relax\tablewidth\hsize
  \let\@floatboxreset\table@boxreset\@float{table}}
  {\end@float}

\newenvironment{conttable*}{\let\@makecaption\@maketablecaption\starttable@hook%
  \let\footnoterule\relax\tablewidth\textwidth
  \let\@floatboxreset\table@boxreset\@dblfloat{table}}
  {\end@dblfloat}

\newenvironment{sidewaysconttable}{%
  \let\@makecaption\@maketablecaption\starttable@hook%
  \let\@floatboxreset\table@boxreset%
  \@rotfloat{table}}
  {\end@rotfloat}



%%%%%%%%%%%%%%% TABNOTE
\newcounter{tabnote}
\def\thetabnote{\@fnsymbol\c@tabnote}

\newenvironment{tabnotes}{}{}

\let\tabnoteref@shape\relax
\def\tabnotemark@fmt#1{\hbox{$^{#1}$}}
%\def\tabnotemark@fmt#1{\@textsuperscript{\normalfont\tabnoteref@shape#1}}

\def\tabnoteref@sep{,}

% Isvedame zymes
\def\tabnoteref{\@ifnextchar[{\@tempswatrue\@tabnoteref}{\@tempswafalse\@tabnoteref[]}}

%% 2007.08.28 \ref pakeistas i \saferef

\def\@tabnoteref[#1]#2{%
  \if@tempswa% []
    \let\tabnoteref@firstref\relax%
    \@for\@@refb:=#2\do{\ifx\relax\tabnoteref@firstref\relax\xdef\tabnoteref@firstref{\@@refb}\fi}%
    \tabnotemark@link{\tabnoteref@firstref}{\tabnotemark@fmt{#1}}%
  \else%
    \let\@tempa\@empty%
    \tabnotemark@fmt{\@for\@tempb:=#2\do{%
       \@tempa\let\@tempa\tabnoteref@sep%
       \edef\@tempb{\expandafter\@firstofone\@tempb\@empty}%
       \saferef{\the\c@table @\@tempb tabnote}}}%
   \fi}

\def\tabnotemark@link#1#2{#2}

% \tabnotemark neturi prasmes:
\def\tabnotemark{\@ifnextchar[{\@tabnotemark}{\@tabnotemark[]}}

\def\@tabnotemark[#1]#2{\@latex@error{Naudokite komanda \string\tabnoteref!}\@ehc}%

% \@tabnotelabel - surisa zyme su label (kaip ir \thankslabel}

\def\@tabnotelabel[#1]#2{%
   \if@tempswa% []
     \protected@edef\@currentlabel{#1}%
   \else% 
     \refstepcounter{tabnote}%
   \fi%
   \safelabel{\the\c@table @#2tabnote}}%

\@ifundefined{safelabel}{\let\safelabel\label}{}


% \tabnotetext isveda zyme ir teksta
\def\first@tabnote{0}

\long\def\tabnotetext{\@ifnextchar[{\@tempswatrue\@tabnotetext}{\@tempswafalse\@tabnotetext[]}}

\long\def\@tabnotetext[#1]#2#3{%
  \@tabnotelabel[#1]{#2}%
  \if@tempswa\ifx.#1.\notabnotemark\fi\fi%
  \ifcase\first@tabnote\firsttabnote@skip\def\first@tabnote{1}\fi%
  \tabnote@skip%
  \parbox[t]{\tablewidth}{\tabnote@size\tabnote@indent\tabnote@hypertarget{#2}\tabnotemark@fmt{\expandafter\saferef{\the\c@table @#2tabnote}}#3\par}%
  \vtop to\z@{ }\par}

\let\tabnote@hypertarget\@gobble
\def\notabnotemark{\global\let\sv@tabnotemark@fmt\tabnotemark@fmt\gdef\tabnotemark@fmt##1{\global\let\tabnotemark@fmt\sv@tabnotemark@fmt}}

\def\legend#1{\tabnotetext[]{}{#1}}

% hooks for *hypermark*
%  \def\tabnotemark@link#1#2{\b@cite@color\hyper@linkstart{link}{\the\c@table @#1tabnote.label}#2\hyper@linkend\e@cite@color}
%  \def\tabnote@hypertarget#1{\hyper@anchorstart{\the\c@table @#1tabnote.label}\strut\hyper@anchorend\e@cite@color}
%  \def\tabnotemark@fmt#1{\hbox{$^{\mathrm{#1}}$}}

%%%%%%%%%%%%%%% TABLE (calc. tablewidth)
\newbox\saved@tabular

\newenvironment{Table}
               {\let\@makecaption\@maketablecaption\starttable@hook%
                \let\caption\tabcaption\let\endtabular\endTabular%
                \let\@floatboxreset\table@boxreset\@float{table}}
               {\end@float}

\newenvironment{Table*}
               {\let\@makecaption\@maketablecaption\starttable@hook%
                \let\caption\tabcaption\let\endtabular\endTabular%
                \let\@floatboxreset\table@boxreset\@dblfloat{table}}
               {\end@dblfloat}

\let\Tabular\tabular
\def\endTabular{\crcr\egroup\egroup $\egroup%$
  \setbox\saved@tabular\lastbox
  \global\tablewidth\the\wd\saved@tabular
  \the\cap@temp\global\cap@temp={}\nointerlineskip
  \leavevmode\box\saved@tabular\par}

\newtoks\cap@temp \cap@temp={}
\def\tabcaption{\refstepcounter\@captype \@dblarg{\@tabcaption\@captype}}
\long\def\@tabcaption#1[#2]#3{%
%  \par
%  \addcontentsline{\csname ext@#1\endcsname}{#1}%
%    {\protect\numberline{\csname the#1\endcsname}{\ignorespaces #2}}%
  \global\cap@temp={%
    \begingroup
      \@parboxrestore
      \if@minipage\@setminipage\fi
      \normalsize\@makecaption{\csname fnum@#1\endcsname}{\ignorespaces #3}\par
    \endgroup}%
  }

%%%%%%%%%%%%%%% HLINE in tabular
   \arrayrulewidth 0.4\p@
   \doublerulesep 2\p@

   \let\savehline\hline
   \def\thline{\noalign{\vskip3pt}\savehline\noalign{\vskip3pt}}%
   \def\fhline{\noalign{\vskip1pt}\savehline\noalign{\vskip7pt}}%
   \def\bhline{\noalign{\vskip3pt}\noalign{\global\arrayrulewidth=1\p@}\savehline\noalign{\global\arrayrulewidth=.5\p@}\noalign{\vskip3pt}}%
   \def\lhline{\noalign{\vskip3pt}\noalign{\global\arrayrulewidth=.3\p@}\savehline\noalign{\global\arrayrulewidth=.5\p@}\noalign{\vskip3pt}}


%%%%%%%%%%%%%%% Advanced \hline - from xmlfloat

\def\oldhline{%
  \noalign{\ifnum0=`}\fi\hrule \@height \arrayrulewidth \futurelet
   \reserved@a\old@xhline}

\def\old@xhline{\ifx\reserved@a\oldhline
               \vskip\doublerulesep
               \vskip-\arrayrulewidth
             \fi
      \ifnum0=`{\fi}}

\def\hline{\noalign{\vskip1\p@}%
  \noalign{\ifnum0=`}\fi\hrule \@height \arrayrulewidth 
  \futurelet\reserved@a\@xhline}

\AtBeginDocument{%
  \def\@xhline{\ifx\reserved@a\hline
    \vskip\doublerulesep\vskip-\arrayrulewidth\fi
    \ifnum0=`{\fi}%
    \noalign{\vskip2\p@}}%
  }

\let\oldcline\cline
\def\cline#1{\noalign{\vskip1\p@}\@cline#1\@nil\noalign{\vskip2\p@}}
\def\ccline#1{\noalign{\vskip1\p@}\do@ccline(#1,1-0)\noalign{\vskip2\p@}}
\def\do@ccline(#1-#2,#3){%
  \noalign{\ifnum#1>#2\gdef\temp@next{}\else\gdef\temp@next{\@cline#1-#2\@nil\do@ccline(#3,1-0)}\fi}%
  \temp@next
  }
\def\no@strut{\global\setbox\@arstrutbox\hbox{\vrule \@height\z@ \@depth\z@ \@width\z@}}%
\def\yes@strut{\global\setbox\@arstrutbox\hbox{%
  \vrule \@height\arraystretch \ht\strutbox \@depth\arraystretch \dp\strutbox \@width\z@}}%

\newdimen\phline@strut@ht
\newdimen\phline@strut@dp

\def\phline#1{%
  \noalign{%
    \do@option@list{phline}{skip=\z@,ht=\z@,dp=\z@}%
    \ifx?#1?\else
      \do@option@list{phline}{#1}%
      \@tempdima\phline@ht\advance\@tempdima\phline@dp\relax
      \ifdim\@tempdima>\z@
        \global\phline@strut@ht\arraystretch\ht\strutbox\global\advance\phline@strut@ht by\phline@ht\relax
        \global\phline@strut@dp\arraystretch\dp\strutbox\global\advance\phline@strut@dp by\phline@dp\relax
        \gdef\noalign@adds{\vrule \@height\phline@strut@ht \@depth\phline@strut@dp\@width\z@}%
        \aftergroup\noalign@adds
      \fi
    \fi
    \vskip-\phline@skip\vskip-\arrayrulewidth\hrule \@height \arrayrulewidth\vskip\phline@skip
    }%
  }

\def\@lrcline[#1-#2]{%
   \noalign{%
     \global\@tempcnta #1\relax
     \global\advance\@tempcnta\m@ne
     \ifnum\@tempcnta>0
        \global \let\@tabklu@tmpa\@lrclinea
     \else
        \global \let\@tabklu@tmpa\@lrclineb
     \fi
     \global \@tempcntb #2\relax
     \global \advance\@tempcntb-\@tempcnta
     }%
     \@tabklu@tmpa
     \noalign{\vskip -\arrayrulewidth}%
  }%

\newtoks\tab@col@span
\def\@lrclinea{%
     \noalign{%
       \loop\expandafter\kaka\expandafter{\the\kaka&\multispan\@ne
     \hbox to 3pt{\hss}%
     \unskip\leaders\hrule \@height \arrayrulewidth\hss
     \hbox to 3pt{\hss}%
}%
\advance\@tempcntb by\m@ne\ifnum\@tempcntb>\z@\repeat
\xdef\ik{\the\kaka}
}%
     \multispan\@tempcnta\ik%\multispan\@tempcntb 
     \cr}%

\def\@lrclineb{%
     \multispan\@tempcntb 
     \hbox to 3pt{\hfil }%
     \unskip\leaders\hrule \@height \arrayrulewidth\hfill
     \hbox to 3pt{\hfil }% 
     \cr}%

\def\lrcline#1{\@lrcline[#1]}%
\def\cdotline#1{\noalign{\vskip1\p@}\@cdotline#1\@nil\noalign{\vskip2\p@}}
\def\@cdotline#1-#2\@nil{%
  \omit
  \@multicnt#1%
  \advance\@multispan\m@ne
  \ifnum\@multicnt=\@ne\@firstofone{&\omit}\fi
  \@multicnt#2%
  \advance\@multicnt-#1%
  \advance\@multispan\@ne
  \cleaders\hb@xt@ .44em{\hss .\hss}\hfill\kern\z@
  \cr
  \noalign{\vskip-\arrayrulewidth}}



%%%%%%%%%%%%%%% CONTCAPTION 

\newif\if@contcaption

\def\contcaptionbraces#1#2{\gdef\contcaptionbraces@left{#1}\gdef\contcaptionbraces@right{#2}}
\contcaptionbraces()

\def\contcaption{\@contcaption\@captype}

\long\def\@contcaption#1#2{%
  \par
  \begingroup
    \@parboxrestore
    \if@minipage\@setminipage\fi
    \@contcaptiontrue
    \normalsize\@makecaption{\csname fnum@#1\endcsname}{\ignorespaces#2}\par
  \endgroup
  }

\def\continued#1{\rightline{(\textit{#1})}}

%%%%%%%%%%%%%%% SIDEWAYSTABLE, SIDEWAYSFIGURE

\def\local@sidewaystable{%
      \let\@makecaption\@maketablecaption%
      \let\@floatboxreset\table@boxreset%
      \@rotfloat{table}}

\def\local@sidewaysfigure{%
      \let\@makecaption\@makefigurecaption%
      \let\@floatboxreset\figure@boxreset%
      \@rotfloat{figure}}

\AtBeginDocument{\let\sidewaysfigure\local@sidewaysfigure\let\sidewaystable\local@sidewaystable%
\@namedef{sidewaysfigure*}{\local@sidewaysfigure}\@namedef{sidewaystable*}{\local@sidewaystable}}



%%%% end   of vtexfltpdf.sty


% figure
\setattribute{figurename}{size}{\bfseries}
\setattribute{figurecaption}{size}{\small}
\def\figurecaption@fmt#1{#1\hfill}

% table
\setattribute{table}{size}{\small}
\setattribute{tablename}{size}{\bfseries}
\setattribute{tablecaption}{size}{\small}
\setattribute{starttable}{hook}{\let\hline\thline}

% ******************** HEADINGS

% Normalus RH
\def\ps@headings{%
      \let\@oddfoot\@empty%
      \let\@evenfoot\@empty%
      \def\@evenhead{\runninghead@size\rlap{\pagenumber@size\thepage}\hfill\leftmark}%
      \def\@oddhead{\runninghead@size\rightmark\hfill\llap{\pagenumber@size\thepage}}%
}%

% Tuscias RH
\def\ps@empty{\let\@mkboth\@gobbletwo%
     \let\@oddhead\@empty%
     \let\@oddfoot\@empty%
     \let\@evenhead\@oddhead%
     \let\@evenfoot\@oddfoot}

% RH  su puslapio numeriu apacioje
\def\ps@plain{\let\@mkboth\@gobbletwo%
     \let\@oddhead\@empty%
     \let\@oddfoot\@empty%
     \let\@evenhead\@oddhead%
     \def\@oddfoot{\hfill\pagenumber@plainsize\thepage\hfill}%
     \let\@evenfoot\@oddfoot}

% First page RH
\def\ps@copyright{\let\@mkboth\@gobbletwo%
  \def\@evenhead{\parbox[c]{\textwidth}{\copyright@size\copyright@text}}%
  \let\@oddhead\@evenhead%
  \def\@oddfoot{\footline@size\footline@text\hfill}%
  \let\@evenfoot\@oddfoot}

% ************************ FOOTNOTE

\let\footnoterule\relax

\DeclareRobustCommand\@makefntext[1]{%
    \parindent10pt\@makefnmark #1}
\def\@makefnmark{\@textsuperscript{\normalfont\@thefnmark}}%

% hook'as hypermark
\def\@makefntext@fmt#1{\parindent10pt\@makefnmark}

\def\freefootnotetext[#1]{%
       \begingroup\unrestored@protected@xdef\@thefnmark{#1}\endgroup\@footnotetext}

% ******************** Sectioning commands

\newcommand\section{\@startsection {section}{1}{\z@}%
                                   {-\bigskipamount}%
                                   {\medskipamount}%
                                   {\Large\bfseries\mathversion{bold}\raggedright}}

\newcommand\subsection{\@startsection {subsection}{2}{\z@}%
                                   {-\bigskipamount}%
                                   {\medskipamount}%
                                   {\large\bfseries\mathversion{bold}\raggedright}}

\newcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                   {-\medskipamount}%
                                   {\smallskipamount}%
                                   {\itshape\raggedright}}

\newcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                   {\medskipamount}%
                                   {-10pt}%
                                   {\itshape}}

\newcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
                                   {0.1pt}%
                                   {-1em}%
                                   {\itshape}}


% Format for the counter:
  \def\section@numbersep{.}
  \def\subsection@numbersep{.}
  \def\subsubsection@numbersep{.}
  \def\paragraph@numbersep{.}
  \def\subparagraph@numbersep{.}

% Format for the counter:
\def\@seccntformat#1{{\csname #1@prefix\endcsname\csname the#1\endcsname\csname#1@numbersep\endcsname\enspace}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% appendix

  \newcommand\appendix{\par
%
    \let\old@section\section%
    \def\section{\@ifnextchar*{\@appsectionstar}{\@appsectionnostar}}%
    \def\section@prefix{\appendixname\ }%
    \def\section@numbersep{:}%
%
    \setcounter{section}{0}%
    \def\thesection{\@Alph\c@section}%
    \@addtoreset{equation}{section}%
    \def\theequation{\thesection.\arabic{equation}}%
    \@addtoreset{thm}{section}%
    \def\thethm{\thesection.\@arabic\c@thm}%
    \@addtoreset{figure}{section}%
    \def\thefigure{\thesection.\arabic{figure}}%
    \@addtoreset{table}{section}%
    \def\thetable{\thesection.\arabic{table}}%
}

  \def\@appsectionstar*#1{%
      \old@section*{#1}%
      \setcounter{section}{1}%
}

  \def\@appsectionnostar#1{%
     \ifx.#1.% 
       \def\section@numbersep{}\old@section[\appendixname\ \thesection]{}%
     \else%
       \def\section@numbersep{:}\old@section[\appendixname\ \thesection: #1]{#1}%
     \fi}


%****************************** FRONTMATTER *
% FRONT MATTER FORMATTING PARAMETERS


\setattribute{frontmatter} {style} {\raggedright}
\setattribute{address}     {style} {\normaltext}
\setattribute{abstract}    {style} {\normaltext}
\setattribute{keyword}     {style} {\raggedright}

% FRONT MATTER SKIPS
\setattribute{title}       {skip} {10\p@}
\setattribute{authors}     {skip} {12\p@}
\setattribute{address}     {skip} {6\p@}
\setattribute{dedicated}   {skip} {12\p@}
\setattribute{abstract}    {skip} {16\p@}
\setattribute{keyword}     {skip} {10\p@}
\setattribute{history}     {skip} {8\p@ plus4pt minus2\p@}
\setattribute{frontmatter} {cmd}  {\vskip20\p@ plus 3\p@ minus 3\p@}

% FRONT MATTER DIMENSIONS
\setattribute{abstract}   {width} {\textwidth}
\setattribute{abstract}  {indent} {\z@} 
\setattribute{keyword}    {width} {\textwidth}
\setattribute{keyword}   {indent} {\z@} %

% FRONT MATTER FONTS 
\setattribute{dochead}    {size} {\normalsize\MakeUppercase}
\setattribute{title}      {size} {\Huge}
\setattribute{author}     {size} {\normalsize}
\setattribute{fnms}       {size} {\uppercase}
\setattribute{snm}        {size} {\uppercase}

\setattribute{address}    {size} {\small\itshape}
\setattribute{dedicated}  {size} {\normalsize\itshape}
\setattribute{abstract}   {size} {\small\upshape}
\setattribute{keyword}    {size} {\small\upshape}
\setattribute{keywordname}{size} {\itshape}
\setattribute{history}    {size} {\raggedright\small\itshape}

\setattribute{runninghead}{size} {\normalsize\itshape}
\setattribute{pagenumber} {size} {\normalsize\upshape}
\setattribute{pagenumber}{plainsize} {\normalsize}
\setattribute{copyright}  {size} {\normalsize}
\setattribute{footline}   {size} {\footnotesize}

% TEXT, etc.
\setattribute{copyright}  {text} {\url@fmt{}{\itshape}{\journal@name}{\journal@url}\ \textbf{\@volume}(\@issue), \the\@pubyear, \@pagerange\\
                                  \@ifundefined{@doi}{}{\url@fmt{\quad DOI: }{}{\@doi}{\doi@base\@doi}}}
\setattribute{footline}   {text} {\journal@issn\quad\copyright@owner}
\setattribute{copyright}  {owner}{\textcopyright\quad\the\@pubyear\ ISI/BS}
\setattribute{author}   {prefix} {}
\setattribute{keyword} {postfix} {}

\setattribute{arxiv}      {text} {This is an electronic reprint of the original article published by the
                                  \url@fmt{}{}{ISI/BS}{\owner@url}\ in 
                                  \url@fmt{}{\itshape}{\journal@name}{\journal@url},
                                  \url@fmt{}{}{\the\@pubyear, \volume@label\ \@volume, \issue@label\ \@issue, \@pagerange}{\doi@base\@doi}.
                                  This reprint differs from the original in pagination and typographic detail.}
\setattribute{arxiv}     {style} {\small\raggedright}


% HISTORY
\setattribute{history}  {prefix}  {}
\setattribute{history}  {postfix} {}
\setattribute{received} {prefix}  {Received~}
\setattribute{received} {postfix} {}
\setattribute{revised}  {prefix}  { and revised~}
\setattribute{revised}  {postfix} {}
\setattribute{accepted} {prefix}  {; accepted~}
\setattribute{accepted} {postfix} {}

% COUNTERS, ETC
\newcounter{author}
\newcounter{address}
\newdimen\sv@mathsurround

% RUNNING HEAD
\def\runtitle#1{\gdef\@runtitle{#1}}                      \def\@runtitle{}
\def\runauthor#1{{\def\etal{et al.}\gdef\@runauthor{#1}}} \def\@runauthor{}

\def\cmd@for@runauthor@elem#1#2#3{\global\@namedef{bej@#1@#2@author}{#3}}
\def\curr@run@aut@fmt#1{\@nameuse{bej@inits@#1@author}\@ifundefined{bej@inits@#1@author}{}{~}\@nameuse{bej@snm@#1@author}}

\def\form@runauthors{%
  \ifx\@runauthor\@empty
    \ifcase\c@author \relax
    \or \gdef\@runauthor{\curr@run@aut@fmt{1}}%
    \or \gdef\@runauthor{\curr@run@aut@fmt{1} and \curr@run@aut@fmt{2}}%
    \or \gdef\@runauthor{\curr@run@aut@fmt{1}, \curr@run@aut@fmt{2} and \curr@run@aut@fmt{3}}%
    \or \gdef\@runauthor{\@nameuse{bej@snm@1@author}, \@nameuse{bej@snm@2@author}, \@nameuse{bej@snm@3@author} and \@nameuse{bej@snm@4@author}}%
    \else \gdef\@runauthor{\curr@run@aut@fmt{1} et al.}%
    \fi
  \fi
}

%**************** pubmonth, doi, aid

\def\aid#1{%
  \def\@tempa{#1}
  \ifx\@tempa\@empty%
    \@latex@error{\string\aid\space numeris negali buti tuscias!}{??}%
  \else\gdef\@aid{#1}\fi}

\def\@aid{<undef>}

% DOI
\def\doi#1{\gdef\@doi{#1}}
\def\@doi{}
\def\doi@base{http://dx.doi.org/}

% referstodoi - nurodo i pagrindinio dokumento DOI 
% (is discusion i pagrindini straipsni)
\def\referstodoi#1{\gdef\@referstodoi{#1}}

% \relateddoi - nurodo isvestinius straipsnius
% (is pagrindinio i isvestinius)

\def\relateddoi{\@ifnextchar[{\@tempswatrue\@relateddoi}{\@tempswafalse\@relateddoi[]}}

\def\@relateddoi[#1]#2#3{%
  \@thankslabel[#1]{#2}%
  \bgroup%
     \def\doi##1{\protect\safe@href{\doi@base##1}{##1}}%
     \protected@xdef\@thanks{\@thanks\protect\thanks@thefnmark{#2thanks}%
     \protect\@footnotetext{\protect\raggedright\thanks@hypertarget{#2}#3}}%
  \egroup%
}%



% \corref
\def\corref#1{}

% \docsubty
\def\docsubty#1{}

%%%%% FRONTMATTER STUFF

\newbox\fm@box
\newdimen\fm@size

\let\hy@frontmatter\relax
\let\hy@endfrontmatter\relax

\def\frontmatter{%
  \global\c@author\z@
  \global\c@address\z@
%
  \def\pdftitle##1{\write@pdfinfo{\user@hy@title}{##1}}
  \def\pdfauthor##1{\write@pdfinfo{\user@hy@author}{##1}}
  \def\pdfsubject##1{\write@pdfinfo{\user@hy@subject}{##1}}
  \def\pdfkeywords##1{\write@pdfinfo{\user@hy@keywords}{##1}}
%
  \sv@mathsurround\mathsurround \m@th
  \parindent\z@
  \hy@frontmatter
  \open@fm \ignorespaces}


% ENDFRONTMATTER
%
\def\endfrontmatter{%
  \global\@topnum\z@
  \set@pagerange
  \form@runauthors
  \markboth{\@runauthor}{\@runtitle}%
  \thispagestyle{copyright}%
%
  \@thanks%
  \arxivnotice@fmt
  \abstract@fmt%
  \keyword@fmt%
%
  \close@fm
%
  \write@pdfinfo{\hy@author}{\the\authors@list}
  \write@pdfinfo{\hy@subject}{\journal@name, \volume@label \@volume, \issue@label \@issue, \the\@pubyear, \@pagerange}
  \write@pdfinfo{\hy@keywords}{\the\keywords@list}
%
  \hy@endfrontmatter
%
  \global\mathsurround\sv@mathsurround
  \global\let\@thanks\@empty  
  \gdef\keyword@exist{0}
%
  \global\c@footnote\c@thanks
%
  \global\@afterindentfalse
  \aftergroup\@afterheading%
  \aftergroup\frontmatter@cmd
  }


\let\maketitle\relax

\newdimen\t@xtheight
\def\init@settings{
\splittopskip=\topskip \splitmaxdepth=\maxdepth
\t@xtheight\textheight \advance\t@xtheight-\splittopskip}

\def\no@harm{\let\thanks=\@gobble\let\thanksref=\@gobble\let~\space\def\ead[##1]##2{}\let\\=\@empty \def\protect{\noexpand\protect\noexpand}}

\def\open@fm{%
  \global\setbox\fm@box=\vbox\bgroup
  \hsize=\textwidth
  \frontmatter@style}

\def\close@fm{%
  \par \egroup
  \fm@size=\dp\fm@box \advance\fm@size by \ht\fm@box
  \@whiledim\fm@size>\t@xtheight \do{%
    \global\setbox\@tempboxa=\vsplit\fm@box to \t@xtheight
    \unvbox\@tempboxa %\newpage
    \fm@size=\dp\fm@box \advance\fm@size by \ht\fm@box}
  \if@twocolumn
    \emergencystretch=1pc \twocolumn[\unvbox\fm@box]
  \else
    \unvbox\fm@box
  \fi}

% DOCHEAD
\def\dochead#1{%
  \bgroup
    \dochead@size
    \leavevmode\vphantom{\strut}#1\par
  \egroup
  \setattribute{title}{skip}{8\p@}}

% TITLE
\def\title#1{%
  \vglue\title@skip%
  \bgroup%
    \no@harm%
    \let\protect\relax%
    \pdfstringdef\@argi{#1}%
  \egroup%
  \write@pdfinfo{\hy@title}{\@argi}
  \bgroup
    \title@size #1\par%
  \egroup}


% AUG - author block
\newenvironment{aug}{}{}

% AUTHOR

\def\and{\unskip~\textup{and}~}

\def\author{\@ifnextchar[{\author@fmt}{\author@fmt[]}}

\def\author@fmt[#1]#2{%
  \stepcounter{author}%
  \author@fmt@init%
  \let\author@fmt@init\relax%
  \bgroup% for PDF metadata
     \def\degs##1{##1}\def\inits##1{}\def\fnms##1{##1}\def\snm##1{##1}\def\roles##1{##1}%
     \ifnum\c@author=1\addto@authors@list{#2}\else\addto@authors@list{, #2}\fi%
  \egroup%
  \bgroup% 
     \def\degs##1{##1}%
     \def\fnms##1{\cmd@for@runauthor@elem{fnms}{\the\c@author}{##1}%
       {\fnms@size{##1}}}%
     \def\inits##1{\cmd@for@runauthor@elem{inits}{\the\c@author}{##1}}%
     \def\snm##1{\cmd@for@runauthor@elem{snm}{\the\c@author}{##1}%
       {\snm@size{##1}}}%
     \def\roles##1{##1}%
     \noindent#2%
  \egroup}


\def\author@fmt@init{%
   \vskip\authors@skip%
   \leavevmode\author@size\author@prefix}

% DEDICATED
\def\dedicated#1{%
  \vskip\dedicated@skip
  \bgroup
    \dedicated@size #1\par
  \egroup}

% ADDRESS
\newcounter{addressref}
\def\theaddressref{\arabic{addressref}}

\def\smart@par{\ifhmode\par\fi}

\def\address{\@ifnextchar[{\address@fmt}{\address@fmt[]}}

\def\address@fmt[#1]#2{%
  \smart@par%
  \vskip\address@skip\def\address@skip{\z@}%
  {\address@style\address@size\leavevmode\ifx.#1.\else\usethankscounter{addressref}\thanksmark{#1}\restorethankscounter\fi#2\par}}


% ABSTRACT

\newbox\abstract@box

\def\abstract{%
     \global\setbox\abstract@box=\vbox\bgroup%
     \@tempdima\textwidth%
     \advance\@tempdima by-\abstract@width%
     \divide\@tempdima by2%
     \abstract@style%
     \leftskip\@tempdima\rightskip\@tempdima%
     \abstract@size%
     \parindent\sv@parindent%
     \noindent\hskip\abstract@indent\abstractname\ignorespaces}
\def\endabstract{\par\egroup}

\def\abstract@fmt{%
  \ifvoid\abstract@box\else
    \vskip\abstract@skip%
    \unvbox\abstract@box
  \fi}

% HISTORY: received, revised, accepted

\def\history@exist{0}

\def\received#1{\def\@tempa{#1}\ifx\@tempa\@empty\else\gdef\@received{#1}\gdef\history@exist{1}\fi}
  \def\@received{\@nil}
\def\revised#1{\def\@tempa{#1}\ifx\@tempa\@empty\else\gdef\@revised{#1}\gdef\history@exist{1}\fi}
  \def\@revised{\@nil}
\def\accepted#1{\def\@tempa{#1}\ifx\@tempa\@empty\else\gdef\@accepted{#1}\gdef\history@exist{1}\fi}
  \def\@accepted{\@nil}

\def\empty@data{\@nil}

\def\history@fmt{%
  \ifcase\history@exist\else%
  \bgroup
    \nobreak%
    \vskip\history@skip%
    \nobreak%
    \history@size
    \leavevmode
    \history@prefix
    \ifx\@received\empty@data \else
      \received@prefix\@received \received@postfix%
    \fi
    \ifx\@revised\empty@data \else
      \revised@prefix\@revised \revised@postfix%
    \fi
    \ifx\@accepted\empty@data \else
      \accepted@prefix\@accepted \accepted@postfix%
    \fi
  \history@postfix\par%
  \egroup%
  \gdef\history@exist{0}
\fi
}

\let\printhistory\history@fmt


\def\sday#1{#1}
\def\smonth#1{\@ifundefined{month@item@#1}%
     {\@latex@error{Nera tokio menesio, kurio numeris #1!}{??}}%
     {\getitemvalue{month}{#1}}%
  }%
\def\syear#1{#1}

\setvaluelist{month}{January,February,March,April,May,June,July,August,September,October,November,December}
\expandafter\def\csname month@item@0\endcsname{????}

% KEYWORDS

\newbox\keyword@box
\newdimen\pre@kwd@depth

\setattribute{keyword}{AMS}{AMS 2000 subject classifications:}
\setattribute{keyword}{KWD}{Keywords:}
% raktas=class
\setattribute[default]{keyword}{class}{KWD}

%  \keyword@class-> KWD
%  \keyword@KWD  -> AMS 2000... 

\gdef\keyword{\@ifnextchar[{\@keyword}{\@keyword[class=KWD]}}

\gdef\@keyword[#1]{%
  \do@option@list{keyword}{#1}%
  \def\keyword@name{\csname keyword@\keyword@class\endcsname}%
  \let\kwd@sep\relax
%
  \global\setbox\keyword@box=\vbox\bgroup%
     \ifvoid\keyword@box\else%
        \unvbox\keyword@box
        \vskip-\pre@kwd@depth\vtop to\pre@kwd@depth{}%
     \fi
     \@tempdima\textwidth%
     \advance\@tempdima by-\keyword@width%
     \divide\@tempdima by2%
     \leftskip\@tempdima\rightskip\@tempdima%
     \keyword@style%
     \keyword@size%
     \parindent\sv@parindent%
     \noindent\hskip\keyword@indent{\keywordname@size\keyword@name}\space\hskip.1pt}

\def\endkeyword{\keyword@postfix\par\global\pre@kwd@depth\prevdepth\egroup}

\def\keyword@fmt{%
  \ifvoid\keyword@box\else
    \vskip\keyword@skip%
    \unvbox\keyword@box
  \fi}


% \kwd[; ]{foo}
  \def\sep{\unskip\string; }%

  \DeclareRobustCommand*\kwd{\@ifnextchar[\@kwd{\@kwd[\kwd@sep]}}%
  \def\@kwd[#1]#2{\unskip#1{#2}\addto@keywords@list{#2, }\let\kwd@sep\sep}%  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% supplement
%
%\begin{supplement}[id=suppA]
%  \sname{Supplement A}
%  \stitle{}
%  \slink[doi]{}
%  \slink[url]{http://lib.stat.cmu.edu/bj/???/???}
%  \sdescription{}
%\end{supplement}
% \thesuppdoi{suppA}
% \ref{suppA}
% \hyperlink{suppA}{text}

\def\supplement@name{Supplementary Material}

\def\sname#1{\def\@sname{#1}\def\@currentlabel{#1}}
\def\stitle#1{\def\@stitle{#1}}
\def\sdatatype#1{\def\@sdatatype{#1}}
\def\@sfilename{}
\def\sfilename#1{\def\@sfilename{}}% AOS tipo XML'ams
\define@key{slink}{text}{\def\sdoi@text{#1}}
\define@key{slink}{doi}[true]{\def\slink@type{doi}}
\define@key{slink}{url}[true]{\def\slink@type{url}}
\def\slink[#1]#2{\setkeys{slink}{#1}\@namedef{slink@\slink@type}{#2}}
\def\sdescription#1{\def\@sdescription{#1}}

\def\suppsection@fmt{\section*{\supplement@name}}

\def\slink@doi@fmt{%
  \url@fmt{DOI: }{}{\@ifundefined{sdoi@text}{\slink@doi}{\sdoi@text}}{\doi@base\slink@doi}%
  \@ifundefined{supp@label}{}{%
    \expandafter\xdef\csname\supp@label @doi\endcsname{\slink@doi}%
    \expandafter\xdef\csname\supp@label @url\endcsname{\doi@base\slink@doi}}%
}

\def\thesuppdoi#1{\@ifundefined{#1@doi}%
  {\@latex@error{Neapibreztas supplement id=#1}{??}}%
  {\def\@tempx{\csname #1@doi\endcsname}%
   \@ifundefined{#1@url}{\def\@tempy{\doi@base\csname #1@url\endcsname}}{\def\@tempy{\csname #1@url\endcsname}}%
   \url@fmt{DOI: }{}{\@tempx}{\@tempy}}%
}

\define@key{supplement}{id}{\def\supp@label{#1}}

\long\def\supplement{\@ifnextchar[{\@supplement}{\@supplement[]}}

\long\def\@supplement[#1]{%
  \suppsection@fmt%
  \global\let\suppsection@fmt\smallskip%
  \setkeys{supplement}{#1}%
}

\def\endsupplement{%
  \noindent\@ifundefined{@sname}{}{\@ifundefined{supp@label}{}{\hypertarget{\supp@label}{}\label{\supp@label}}\textbf{\@sname: }}%
  \@ifundefined{@stitle}{}{\textbf{\@stitle\ }}%
%
  (%
  \@ifundefined{slink@doi}{}{\slink@doi@fmt}%
  \@ifundefined{@sdatatype}{}{; \@sdatatype}%
  \@ifundefined{@sfilename}{}{\@sfilename}%
  ).
  \@ifundefined{@sdescription}{}{\@sdescription}%
  \par}


%%%%%%%%%  special notice of arXiv:

\def\arxivnotice@fmt{%
  \bgroup
    \protected@xdef\@thefnmark{}
    \safe@footnotetext{\vskip-3\p@\noindent\fbox{\parbox{\columnwidth}{\arxiv@style\arxiv@text}}}
  \egroup}

\long\def\safe@footnotetext#1{\insert\footins{%
    \reset@font\footnotesize
    \interlinepenalty\interfootnotelinepenalty
    \splittopskip\footnotesep
    \splitmaxdepth \dp\strutbox \floatingpenalty \@MM
    \hsize\columnwidth \@parboxrestore
    \color@begingroup
      \@makefntext{%
        \rule\z@\footnotesep\ignorespaces #1\@finalstrut\strutbox}%
    \color@endgroup}}%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% url@fmt
% {prefix}{font}{text}{url}

\def\url@fmt#1#2#3#4{%
   \edef\@tempa{#3}%
   \ifx\@tempa\@empty%
   \else%
     #1{#2\safe@href{#4}{#3}}%
   \fi}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% interaction with hyperref

\def\pdfstringdef#1#2{}

\def\test@hyperref{\@ifundefined{Hy@SetCatcodes}{}{\imsart@hyperref@settings}}

\AtBeginDocument{\test@hyperref}

\def\imsart@hyperref@settings{%
% activate href
   \let\ims@href\href%
   \let\safe@href\href
   \let\safe@phantomsection\phantomsection
%
   \def\thankref@hyperlink##1{\edef\@tempx{##1thanks}\hbox{\hyperlink{##1}{\saferef{\@tempx}}}}
   \def\thanks@hypertarget##1{\smash{\raise\baselineskip\hbox{\protect\hypertarget{##1}{}}}}
   \def\thanksmark@link##1##2{\hyperlink{##1}{##2}}
%
% put document info
   \def\write@pdfinfo##1##2{\protected@write\@auxout{\no@harm}{\string\gdef\string##1{##2}}}
   \@ifundefined{hy@title}{}{\pdfstringdef\@pdftitle{\hy@title}}
   \@ifundefined{hy@author}{}{\pdfstringdef\@pdfauthor{\hy@author}}
   \@ifundefined{hy@subject}{}{\pdfstringdef\@pdfsubject{\hy@subject}}
   \@ifundefined{hy@keywords}{}{\pdfstringdef\@pdfkeywords{\hy@keywords}}
%
   \@ifundefined{user@hy@title}{}{\global\let\@pdftitle\user@hy@title}
   \@ifundefined{user@hy@author}{}{\global\let\@pdfauthor\user@hy@author}
   \@ifundefined{user@hy@subject}{}{\global\let\@pdfsubject\user@hy@subject}
   \@ifundefined{user@hy@keywords}{}{\global\let\@pdfkeywords\user@hy@keywords}
%
%   \def\saferef##1{\expandafter\safe@setref\csname r@##1\endcsname\@firstoffive{##1}}
%
% Define colors: 
  \hypersetup{
     colorlinks=true,
     linkcolor=blue,
     citecolor=blue,
     urlcolor =blue
             }
% MathSciNet:
   \def\MR##1{\href{http://www.ams.org/mathscinet-getitem?mr=##1}{MR##1}}
}

\def\write@pdfinfo#1#2{}

\newtoks\authors@list
\def\addto@authors@list#1{%
  \begingroup%
    \no@harm%
    \xdef\@act{\global\noexpand\authors@list{\the\authors@list#1}}\@act%
  \endgroup}

\newtoks\keywords@list
\def\addto@keywords@list#1{%
  \begingroup%
    \no@harm%
    \xdef\@act{\global\noexpand\keywords@list{\the\keywords@list#1}}\@act%
  \endgroup}

% MathSciNet:
\def\MR#1{MR#1}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% msnbibl.sty
\if@MSNbibl

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% bibitem

  \def\endbibitem{\set@msnbibl\let\endbibitem\relax}

  \def\set@msnbibl{\protected@write\@auxout{}{\string\global\string\let\string\bibitem\string\msn@bibitem}{}}

  \let\real@bibitem\bibitem

  \long\def\msn@bibitem#1\endbibitem{%
     \real@bibitem#1\endbibitem
    }%


  \def\bbl@MR#1{#1}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% get@MR

  \def\get@MR#1R#2 #3\end{\MR{#2}}

  \let\MR@fmt\@firstofone

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Common macros:

  % Setting a "style" for a command:
  % \set@bibl@cmd{bvolume}  == \def\bvolume#1{{\bvolume@style #1}}

  \def\set@bibl@cmd#1{\expandafter\def\csname #1\endcsname##1{{\csname #1@style\endcsname##1}}}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

  \def\get@battribute#1{\ifx.#1.\else\def\b@attribute{#1}\fi}

  \let\show@battribute\relax

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% bauthor, beditor

  \def\bbl@bauthor#1{{%
    \let\binits\@firstofone%
    \let\bsnm\@firstofone%
    \let\bfnm\@gobble%
    \let\bparticle\@firstofone%
    \let\bsuffix\@firstofone%
    \bauthor@style%
  #1}}

  \def\bbl@beditor#1{{%
    \let\binits\@firstofone%
    \let\bsnm\@firstofone%
    \let\bfnm\@gobble%
    \let\bparticle\@firstofone%
    \let\bsuffix\@firstofone%
    \beditor@style%
  #1}}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% bid
  % \bid{MR={},doi={},...}

  \define@key{bid}{mr}{\get@MR MR#1 \end\ignorespaces}
  \define@key{bid}{doi}{}
  \define@key{bid}{pubmed}{}
  \define@key{bid}{pii}{}
  \define@key{bid}{issn}{}
  \define@key{bid}{pmid}{}
  \define@key{bid}{pmcid}{}
  \define@key{bid}{mid}{}

  \def\bbl@bid#1{%
         \setkeys{bid}{#1}%
  }

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% common@pub@types

  \def\common@pub@types{%
    \def\AND{and }%
  \let\betal\@firstofone%
    \set@bibl@cmd{btitle}
    \let\byear\@firstofone%  
    \let\bpages\@firstofone%
    \let\bmisc\@firstofone%
    \let\bnote\@firstofone%
    \let\banumber\@firstofone%
    \def\bmrnumber##1{\get@MR##1 \end\ignorespaces}%
    \let\bid\bbl@bid%
    \let\bptnote\@gobble% 
    \set@bibl@cmd{bvolume}%
    \csname common@pub@types@hook\endcsname%
  }


  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% default stiliai

    \setattribute{bauthor}{style}{\scshape}
    \setattribute{beditor}{style}{\scshape}

    \setattribute{bjournal}  {style}{\itshape}
    \setattribute{bbooktitle}{style}{\itshape}
    \setattribute{bseries}   {style}{\itshape}

    \setattribute{bvolume}   {style}{\bfseries}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  barticle

  \def\barticle{\@ifnextchar[{\@barticle}{\@barticle[]}}

  \def\@barticle[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \set@bibl@cmd{bjournal}%
  }

  \def\endbarticle{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% bbook

  \def\bbook{\@ifnextchar[{\@bbook}{\@bbook[]}}

  \def\@bbook[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \let\beditor\bbl@beditor%
    \let\bedition\@firstofone%
    \set@bibl@cmd{bseries}%
    \let\bpublisher\@firstofone%
    \let\baddress\@firstofone%
    \let\blocation\@firstofone%
    \let\bisbn\@gobble%
  %
    \let\btitle@style\itshape
  }

  \def\endbbook{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% bincollection

  \def\bincollection{\@ifnextchar[{\@bincollection}{\@bincollection[]}}

  \def\@bincollection[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \let\beditor\bbl@beditor%
    \set@bibl@cmd{bbooktitle}%
    \let\bchapter\@firstofone%
    \let\bedition\@firstofone%
    \set@bibl@cmd{bseries}%
    \let\bpublisher\@firstofone%
    \let\baddress\@firstofone%
    \let\blocation\@firstofone%
    \let\bisbn\@gobble%
  }

  \def\endbincollection{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% binproceedings

  \def\binproceedings{\@ifnextchar[{\@binproceedings}{\@binproceedings[]}}

  \def\@binproceedings[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \let\beditor\bbl@beditor%
    \set@bibl@cmd{bbooktitle}%
    \set@bibl@cmd{bseries}%
    \let\borganization\@firstofone%
    \let\bpublisher\@firstofone%
    \let\baddress\@firstofone%
    \let\blocation\@firstofone%
    \let\bisbn\@gobble%
  }

  \def\endbinproceedings{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% binbook

  \def\binbook{\@ifnextchar[{\@binbook}{\@binbook[]}}

  \def\@binbook[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \let\beditor\bbl@beditor%
    \set@bibl@cmd{bbooktitle}%
    \let\bchapter\@firstofone%
    \let\bedition\@firstofone%
    \set@bibl@cmd{bseries}%
    \let\bpublisher\@firstofone%
    \let\baddress\@firstofone%
    \let\blocation\@firstofone%
    \let\bisbn\@gobble%
  %
    \let\btitle@style\itshape
  }

  \def\endbinbook{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% bproceedings

  \def\bproceedings{\@ifnextchar[{\@bproceedings}{\@bproceedings[]}}

  \def\@bproceedings[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \let\beditor\bbl@beditor%
    \let\bedition\@firstofone%
    \set@bibl@cmd{bseries}%
    \let\bpublisher\@firstofone%
    \let\borganization\@firstofone%
    \let\baddress\@firstofone%
    \let\blocation\@firstofone%
    \let\bisbn\@gobble%
  %
    \let\btitle@style\itshape
  }

  \def\bproceedings{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% btechreport

  \def\btechreport{\@ifnextchar[{\@btechreport}{\@btechreport[]}}

  \def\@btechreport[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \let\btype\@firstofone%
    \let\bnumber\@firstofone%
    \let\binstitution\@firstofone%
    \let\baddress\@firstofone%
    \let\blocation\@firstofone%
  }

  \def\endbtechreport{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% bmanual

  \def\bmanual{\@ifnextchar[{\@bmanual}{\@bmanual[]}}

  \def\@bmanual[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \let\bedition\@firstofone%
    \let\borganization\@firstofone%
    \let\baddress\@firstofone%
    \let\blocation\@firstofone%
    \let\bisbn\@gobble%
  }

  \def\endbmanual{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% mastersthesis

  \def\bmastersthesis{\@ifnextchar[{\@bmastersthesis}{\@bmastersthesis[]}}

  \def\@bmastersthesis[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \let\bschool\@firstofone%
    \let\btype\@firstofone%
    \let\baddress\@firstofone%
    \let\blocation\@firstofone%
  }

  \def\endbmastersthesis{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% phdthesis

  \def\bphdthesis{\@ifnextchar[{\@bphdthesis}{\@bphdthesis[]}}

  \def\@bphdthesis[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \let\bschool\@firstofone%
    \let\btype\@firstofone%
    \let\baddress\@firstofone%
    \let\blocation\@firstofone%
  }

  \def\endbphdthesis{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% bbooklet

  \def\bbooklet{\@ifnextchar[{\@bbooklet}{\@bbooklet[]}}

  \def\@bbooklet[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \let\bhowpublished\@firstofone%
    \let\baddress\@firstofone%
    \let\blocation\@firstofone%
  }

  \def\endbbooklet{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% bunpublished

  \def\bunpublished{\@ifnextchar[{\@bunpublished}{\@bunpublished[]}}

  \def\@bunpublished[#1]{%
    \get@battribute{#1}%
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
  }

  \def\endbunpublished{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% bmisc

  \def\bmisc{\@ifnextchar[{\@bmisc}{\@bmisc[]}}

  \def\@bmisc[#1]{%
    \get@battribute{unstr}%  
    \common@pub@types%
    \let\bauthor\bbl@bauthor%
    \let\bhowpublished\@firstofone%
    \let\borganization\@firstofone%
  }

  \def\endbmisc{\show@battribute\aftergroup\ignorespaces}

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% \bptok

  \def\bptok#1{\ignorespaces}

\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% vtexurl.sty

%%%%%%%%%%%%%%%%%%% \doiurl

%% \doiurl{http://dx.doi.org/00000.0000}
%% \doiurl{00000.0000}
%% \doiurl{http://\\dx.doi.org/00000.0000}
%% \doiurl{00000.\\0000}

\@ifundefined{doi@base}{\def\doi@base{http://dx.doi.org/}}{}

\DeclareRobustCommand\doiurl[1]{{%
 \def\\{}%
 \check@doiurl@prefix#1http://\end%
 \check@doiurl@break#1\\\end\relax%
 \if@doiurlbreak%
    \@ifundefined{doi@url}{%
       \href{\doi@base\@tempx\@tempy}{\csname doi@size\endcsname\@tempx}%
       \break%
       \href{\doi@base\@tempx\@tempy}{\csname doi@size\endcsname\@tempy}}%
                          {%
       \expandafter\href{\@tempx\@tempy}{\csname doi@size\endcsname\@tempx}%
       \break%
       \href{\@tempx\@tempy}{\csname doi@size\endcsname\@tempy}}%
 \else%
    \@ifundefined{doi@url}%
        {\href{\doi@base#1}{\csname doi@size\endcsname #1}}%
        {\href{#1}{\csname doi@size\endcsname #1}}%
 \fi}}


\def\check@doiurl@prefix#1http://#2\end{\ifx.#2.\else\def\doi@url{fullurl}\fi}

\newif\if@doiurlbreak \@doiurlbreakfalse

\def\check@doiurl@break#1\\#2\end{%
    \ifx.#2.\@doiurlbreakfalse%
    \else%
       \@doiurlbreaktrue%
       \def\@tempx{#1}%
       \def\@tempy{#2}%
    \fi}

%%%%%%%%%%%%%%%%%%% arxivurl

%% \arxivurl{http://arxiv.org/abs/math.PR/0603300}
%% \arxivurl{math.PR/0603300}
%% \arxivurl{http://\\arxiv.org/abs/math.PR/0603300}
%% \arxivurl{math.PR/\\0603300}

\@ifundefined{arxiv@base}{\def\arxiv@base{http://arxiv.org/abs/}}{}

\DeclareRobustCommand\arxivurl[1]{{%
 \def\\{}%
 \check@arxivurl@prefix#1http://\end%
 \check@arxivurl@break#1\\\end\relax%
 \if@arxivurlbreak%
    \@ifundefined{arxiv@url}{%
       \href{\arxiv@base\@tempx\@tempy}{\csname arxivurl@size\endcsname\@tempx}%
       \break%
       \href{\arxiv@base\@tempx\@tempy}{\csname arxivurl@size\endcsname\@tempy}}%
                            {%
       \expandafter\href{\@tempx\@tempy}{\csname arxivurl@size\endcsname\@tempx}%
       \break%
       \href{\@tempx\@tempy}{\csname arxivurl@size\endcsname\@tempy}}%
 \else%
    \@ifundefined{arxiv@url}%
        {\href{\arxiv@base#1}{\csname arxivurl@size\endcsname #1}}%
        {\href{#1}{\csname arxivurl@size\endcsname #1}}%
 \fi}}


\def\check@arxivurl@prefix#1http://#2\end{\ifx.#2.\else\def\arxiv@url{fullurl}\fi}

\newif\if@arxivurlbreak \@arxivurlbreakfalse

\def\check@arxivurl@break#1\\#2\end{%
    \ifx.#2.\@arxivurlbreakfalse%
    \else%
       \@arxivurlbreaktrue%
       \def\@tempx{#1}%
       \def\@tempy{#2}%
    \fi}


%%%%%%%%%%%%%%%%%%% surl

%% \surl{http://www.foo.com/something}
%% \surl{ftp://ftp.foo.com/something}
%% \surl{www.foo.com/something}
%% \surl{http://www.foo.com/\\something}
%% \surl{ftp://\\ftp.foo.com/\\something}
%% \surl{www.foo.com/\\something}

\def\spliturl@prefix{http://}

\DeclareRobustCommand\surl[1]{{%
 \def\\{}%
 \check@spliturl@prefix#1://\end%
 \check@spliturl@break#1\\\end\relax%
 \if@spliturlbreak%
    \@ifundefined{spliturl@url}{%
       \href{\spliturl@prefix\@tempx\@tempy}{\csname surl@size\endcsname\@tempx}%
       \break%
       \href{\spliturl@prefix\@tempx\@tempy}{\csname surl@size\endcsname\@tempy}}%
                            {%
       \expandafter\href{\@tempx\@tempy}{\csname surl@size\endcsname\@tempx}%
       \break%
       \href{\@tempx\@tempy}{\csname surl@size\endcsname\@tempy}}%
 \else%
    \@ifundefined{spliturl@url}%
        {\href{\spliturl@prefix#1}{\csname surl@size\endcsname #1}}%
        {\href{#1}{\csname surl@size\endcsname #1}}%
 \fi}}


\def\check@spliturl@prefix#1://#2\end{\ifx.#2.\else\def\spliturl@url{fullurl}\fi}

\newif\if@spliturlbreak \@spliturlbreakfalse

\def\check@spliturl@break#1\\#2\end{%
    \ifx.#2.\@spliturlbreakfalse%
    \else%
       \@spliturlbreaktrue%
       \def\@tempx{#1}%
       \def\@tempy{#2}%
    \fi}


%%%%%%%%%%%%%%%%%%% shref
%% \shref{http://www.foo.com/something}{http://\\www.\\foo.\\com/something}

\DeclareRobustCommand\shref[2]{%
 \def\split@href@prefix{}%
 \fmt@split@href[#1]#2\\\\%
 }


\def\fmt@split@href[#1]#2\\{%
   \ifx.#2.\def\next[##1]#2{}%
   \else \split@href@prefix\href{#1}{\csname surl@size\endcsname#2}%
         \gdef\split@href@prefix{\break}%
         \let\next\fmt@split@href
   \fi\next[#1]}

%%%%%%%%%%%%%%%%%% semail (split email)
%% \semail{mailto@foo.\\something.\\lt}

%%
\def\semail@prefix{mailto:}
\DeclareRobustCommand\semail[1]%
{%
 \bgroup
  \let\\\@empty
  \def\_{\string_}%
  \xdef\@tempa{#1}%
 \egroup%
 \shref{\semail@prefix\@tempa}{#1}%
}

%**************** nereikalingi apibrezimai:
\let\HPROOF\relax
\let\PROOF\relax
\let\CRC\relax
\let\psdraft\relax
\let\psfull\relax
\let\vtexed\@gobble
\def\vktinfo#1#2#3{}
\let\abslp\@gobble
\let\usrlp\@gobble
\let\vktcmnlpabslp\@gobble
\let\vktcmnlpusrlp\@gobble

%**************** INICIALIZATION
%
% DIMENSIONS

\@twosidetrue
\pagenumbering{arabic}
\frenchspacing
\init@settings
\pagestyle{headings}


\endinput

%%
%% End of file `arxbj.cls'.
